/*   -*- buffer-read-only: t -*- vi: set ro:
 *
 *  DO NOT EDIT THIS FILE   (certtool-args.c)
 *
 *  It has been AutoGen-ed
 *  From the definitions    certtool-args.def
 *  and the template file   options
 *
 * Generated from AutoOpts 41:1:16 templates.
 *
 *  AutoOpts is a copyrighted work.  This source file is not encumbered
 *  by AutoOpts licensing, but is provided under the licensing terms chosen
 *  by the certtool author or copyright holder.  AutoOpts is
 *  licensed under the terms of the LGPL.  The redistributable library
 *  (``libopts'') is licensed under the terms of either the LGPL or, at the
 *  users discretion, the BSD license.  See the AutoOpts and/or libopts sources
 *  for details.
 *
 * The certtool program is copyrighted and licensed
 * under the following terms:
 *
 *  Copyright (C) 2000-2016 Free Software Foundation, and others, all rights reserved.
 *  This is free software. It is licensed for use, modification and
 *  redistribution under the terms of the GNU General Public License,
 *  version 3 or later <http://gnu.org/licenses/gpl.html>
 *
 *  certtool is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  certtool is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __doxygen__
#define OPTION_CODE_COMPILE 1
#include "certtool-args.h"
#include <sys/types.h>

#include <limits.h>
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#ifdef  __cplusplus
extern "C" {
#endif
extern FILE * option_usage_fp;
#define zCopyright      (certtool_opt_strs+0)
#define zLicenseDescrip (certtool_opt_strs+284)


#ifndef NULL
#  define NULL 0
#endif

/**
 *  static const strings for certtool options
 */
static char const certtool_opt_strs[6462] =
/*     0 */ "certtool 3.4.15\n"
            "Copyright (C) 2000-2016 Free Software Foundation, and others, all rights reserved.\n"
            "This is free software. It is licensed for use, modification and\n"
            "redistribution under the terms of the GNU General Public License,\n"
            "version 3 or later <http://gnu.org/licenses/gpl.html>\n\0"
/*   284 */ "certtool is free software: you can redistribute it and/or modify it under\n"
            "the terms of the GNU General Public License as published by the Free\n"
            "Software Foundation, either version 3 of the License, or (at your option)\n"
            "any later version.\n\n"
            "certtool is distributed in the hope that it will be useful, but WITHOUT ANY\n"
            "WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS\n"
            "FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more\n"
            "details.\n\n"
            "You should have received a copy of the GNU General Public License along\n"
            "with this program.  If not, see <http://www.gnu.org/licenses/>.\n\0"
/*   889 */ "Enable debugging\0"
/*   906 */ "DEBUG\0"
/*   912 */ "debug\0"
/*   918 */ "More verbose output\0"
/*   938 */ "VERBOSE\0"
/*   946 */ "verbose\0"
/*   954 */ "Input file\0"
/*   965 */ "INFILE\0"
/*   972 */ "infile\0"
/*   979 */ "Output file\0"
/*   991 */ "OUTFILE\0"
/*   999 */ "outfile\0"
/*  1007 */ "Generate a self-signed certificate\0"
/*  1042 */ "GENERATE_SELF_SIGNED\0"
/*  1063 */ "generate-self-signed\0"
/*  1084 */ "Generate a signed certificate\0"
/*  1114 */ "GENERATE_CERTIFICATE\0"
/*  1135 */ "generate-certificate\0"
/*  1156 */ "Generates a proxy certificate\0"
/*  1186 */ "GENERATE_PROXY\0"
/*  1201 */ "generate-proxy\0"
/*  1216 */ "Generate a CRL\0"
/*  1231 */ "GENERATE_CRL\0"
/*  1244 */ "generate-crl\0"
/*  1257 */ "Update a signed certificate\0"
/*  1285 */ "UPDATE_CERTIFICATE\0"
/*  1304 */ "update-certificate\0"
/*  1323 */ "Generate a private key\0"
/*  1346 */ "GENERATE_PRIVKEY\0"
/*  1363 */ "generate-privkey\0"
/*  1380 */ "Generate a PKCS #10 certificate request\0"
/*  1420 */ "GENERATE_REQUEST\0"
/*  1437 */ "generate-request\0"
/*  1454 */ "Verify a PEM encoded certificate chain\0"
/*  1493 */ "VERIFY_CHAIN\0"
/*  1506 */ "verify-chain\0"
/*  1519 */ "Verify a PEM encoded certificate chain using a trusted list\0"
/*  1579 */ "VERIFY\0"
/*  1586 */ "verify\0"
/*  1593 */ "Verify a CRL using a trusted list\0"
/*  1627 */ "VERIFY_CRL\0"
/*  1638 */ "verify-crl\0"
/*  1649 */ "Specify a hostname to be used for certificate chain verification\0"
/*  1714 */ "VERIFY_HOSTNAME\0"
/*  1730 */ "verify-hostname\0"
/*  1746 */ "Specify a email to be used for certificate chain verification\0"
/*  1808 */ "VERIFY_EMAIL\0"
/*  1821 */ "verify-email\0"
/*  1834 */ "Specify a purpose OID to be used for certificate chain verification\0"
/*  1902 */ "VERIFY_PURPOSE\0"
/*  1917 */ "verify-purpose\0"
/*  1932 */ "Generate PKCS #3 encoded Diffie-Hellman parameters\0"
/*  1983 */ "GENERATE_DH_PARAMS\0"
/*  2002 */ "generate-dh-params\0"
/*  2021 */ "Get the included PKCS #3 encoded Diffie-Hellman parameters\0"
/*  2080 */ "GET_DH_PARAMS\0"
/*  2094 */ "get-dh-params\0"
/*  2108 */ "Print information PKCS #3 encoded Diffie-Hellman parameters\0"
/*  2168 */ "DH_INFO\0"
/*  2176 */ "dh-info\0"
/*  2184 */ "Loads a private key file\0"
/*  2209 */ "LOAD_PRIVKEY\0"
/*  2222 */ "load-privkey\0"
/*  2235 */ "Loads a public key file\0"
/*  2259 */ "LOAD_PUBKEY\0"
/*  2271 */ "load-pubkey\0"
/*  2283 */ "Loads a certificate request file\0"
/*  2316 */ "LOAD_REQUEST\0"
/*  2329 */ "load-request\0"
/*  2342 */ "Loads a certificate file\0"
/*  2367 */ "LOAD_CERTIFICATE\0"
/*  2384 */ "load-certificate\0"
/*  2401 */ "Loads the certificate authority's private key file\0"
/*  2452 */ "LOAD_CA_PRIVKEY\0"
/*  2468 */ "load-ca-privkey\0"
/*  2484 */ "Loads the certificate authority's certificate file\0"
/*  2535 */ "LOAD_CA_CERTIFICATE\0"
/*  2555 */ "load-ca-certificate\0"
/*  2575 */ "Loads the provided CRL\0"
/*  2598 */ "LOAD_CRL\0"
/*  2607 */ "load-crl\0"
/*  2616 */ "Loads auxilary data\0"
/*  2636 */ "LOAD_DATA\0"
/*  2646 */ "load-data\0"
/*  2656 */ "Password to use\0"
/*  2672 */ "PASSWORD\0"
/*  2681 */ "password\0"
/*  2690 */ "Enforce a NULL password\0"
/*  2714 */ "NULL_PASSWORD\0"
/*  2728 */ "null-password\0"
/*  2742 */ "Enforce an empty password\0"
/*  2768 */ "EMPTY_PASSWORD\0"
/*  2783 */ "empty-password\0"
/*  2798 */ "Print big number in an easier format to parse\0"
/*  2844 */ "HEX_NUMBERS\0"
/*  2856 */ "hex-numbers\0"
/*  2868 */ "In certain operations it prints the information in C-friendly format\0"
/*  2937 */ "CPRINT\0"
/*  2944 */ "cprint\0"
/*  2951 */ "Print information on the given certificate\0"
/*  2994 */ "CERTIFICATE_INFO\0"
/*  3011 */ "certificate-info\0"
/*  3028 */ "Print the fingerprint of the given certificate\0"
/*  3075 */ "FINGERPRINT\0"
/*  3087 */ "fingerprint\0"
/*  3099 */ "Print the key ID of the given certificate\0"
/*  3141 */ "KEY_ID\0"
/*  3148 */ "key-id\0"
/*  3155 */ "Print certificate's public key\0"
/*  3186 */ "CERTIFICATE_PUBKEY\0"
/*  3205 */ "certificate-pubkey\0"
/*  3224 */ "Print information on the given OpenPGP certificate\0"
/*  3275 */ "PGP_CERTIFICATE_INFO\0"
/*  3296 */ "pgp-certificate-info\0"
/*  3317 */ "Print information on the given OpenPGP keyring structure\0"
/*  3374 */ "PGP_RING_INFO\0"
/*  3388 */ "pgp-ring-info\0"
/*  3402 */ "Print information on the given CRL structure\0"
/*  3447 */ "CRL_INFO\0"
/*  3456 */ "crl-info\0"
/*  3465 */ "Print information on the given certificate request\0"
/*  3516 */ "CRQ_INFO\0"
/*  3525 */ "crq-info\0"
/*  3534 */ "Do not use extensions in certificate requests\0"
/*  3580 */ "NO_CRQ_EXTENSIONS\0"
/*  3598 */ "no-crq-extensions\0"
/*  3616 */ "Print information on a PKCS #12 structure\0"
/*  3658 */ "P12_INFO\0"
/*  3667 */ "p12-info\0"
/*  3676 */ "The PKCS #12 friendly name to use\0"
/*  3710 */ "P12_NAME\0"
/*  3719 */ "p12-name\0"
/*  3728 */ "Generate a PKCS #7 structure\0"
/*  3757 */ "P7_GENERATE\0"
/*  3769 */ "p7-generate\0"
/*  3781 */ "Signs using a PKCS #7 structure\0"
/*  3813 */ "P7_SIGN\0"
/*  3821 */ "p7-sign\0"
/*  3829 */ "Signs using a detached PKCS #7 structure\0"
/*  3870 */ "P7_DETACHED_SIGN\0"
/*  3887 */ "p7-detached-sign\0"
/*  3904 */ "The signer's certificate will be included in the cert list.\0"
/*  3964 */ "P7_INCLUDE_CERT\0"
/*  3980 */ "no-p7-include-cert\0"
/*  3999 */ "no\0"
/*  4002 */ "Will include a timestamp in the PKCS #7 structure\0"
/*  4052 */ "P7_TIME\0"
/*  4060 */ "p7-time\0"
/*  4068 */ "Will show the embedded data in the PKCS #7 structure\0"
/*  4121 */ "P7_SHOW_DATA\0"
/*  4134 */ "no-p7-show-data\0"
/*  4150 */ "Print information on a PKCS #7 structure\0"
/*  4191 */ "P7_INFO\0"
/*  4199 */ "p7-info\0"
/*  4207 */ "Verify the provided PKCS #7 structure\0"
/*  4245 */ "P7_VERIFY\0"
/*  4255 */ "p7-verify\0"
/*  4265 */ "Print information on a PKCS #8 structure\0"
/*  4306 */ "P8_INFO\0"
/*  4314 */ "p8-info\0"
/*  4322 */ "Convert S/MIME to PKCS #7 structure\0"
/*  4358 */ "SMIME_TO_P7\0"
/*  4370 */ "smime-to-p7\0"
/*  4382 */ "Print information on a private key\0"
/*  4417 */ "KEY_INFO\0"
/*  4426 */ "key-info\0"
/*  4435 */ "Print information on an OpenPGP private key\0"
/*  4479 */ "PGP_KEY_INFO\0"
/*  4492 */ "pgp-key-info\0"
/*  4505 */ "Print information on a public key\0"
/*  4539 */ "PUBKEY_INFO\0"
/*  4551 */ "pubkey-info\0"
/*  4563 */ "Generate an X.509 version 1 certificate (with no extensions)\0"
/*  4624 */ "V1\0"
/*  4627 */ "v1\0"
/*  4630 */ "Generate a PKCS #12 structure\0"
/*  4660 */ "TO_P12\0"
/*  4667 */ "to-p12\0"
/*  4674 */ "Generate a PKCS #8 structure\0"
/*  4703 */ "TO_P8\0"
/*  4709 */ "to-p8\0"
/*  4715 */ "Use PKCS #8 format for private keys\0"
/*  4751 */ "PKCS8\0"
/*  4757 */ "pkcs8\0"
/*  4763 */ "Generate RSA key\0"
/*  4780 */ "RSA\0"
/*  4784 */ "rsa\0"
/*  4788 */ "Generate DSA key\0"
/*  4805 */ "DSA\0"
/*  4809 */ "dsa\0"
/*  4813 */ "Generate ECC (ECDSA) key\0"
/*  4838 */ "ECC\0"
/*  4842 */ "ecc\0"
/*  4846 */ "an alias for the 'ecc' option\0"
/*  4876 */ "ecdsa\0"
/*  4882 */ "Hash algorithm to use for signing\0"
/*  4916 */ "HASH\0"
/*  4921 */ "hash\0"
/*  4926 */ "Use DER format for input certificates, private keys, and DH parameters\0"
/*  4997 */ "INDER\0"
/*  5003 */ "no-inder\0"
/*  5012 */ "an alias for the 'inder' option\0"
/*  5044 */ "inraw\0"
/*  5050 */ "Use DER format for output certificates, private keys, and DH parameters\0"
/*  5122 */ "OUTDER\0"
/*  5129 */ "no-outder\0"
/*  5139 */ "an alias for the 'outder' option\0"
/*  5172 */ "outraw\0"
/*  5179 */ "Specify the number of bits for key generate\0"
/*  5223 */ "BITS\0"
/*  5228 */ "bits\0"
/*  5233 */ "Specify the curve used for EC key generation\0"
/*  5278 */ "CURVE\0"
/*  5284 */ "curve\0"
/*  5290 */ "Specify the security level [low, legacy, medium, high, ultra]\0"
/*  5352 */ "SEC_PARAM\0"
/*  5362 */ "sec-param\0"
/*  5372 */ "No effect\0"
/*  5382 */ "DISABLE_QUICK_RANDOM\0"
/*  5403 */ "disable-quick-random\0"
/*  5424 */ "Template file to use for non-interactive operation\0"
/*  5475 */ "TEMPLATE\0"
/*  5484 */ "template\0"
/*  5493 */ "Print information to stdout instead of stderr\0"
/*  5539 */ "STDOUT_INFO\0"
/*  5551 */ "stdout-info\0"
/*  5563 */ "Enable interaction for entering password when in batch mode.\0"
/*  5624 */ "ASK_PASS\0"
/*  5633 */ "ask-pass\0"
/*  5642 */ "Cipher to use for PKCS #8 and #12 operations\0"
/*  5687 */ "PKCS_CIPHER\0"
/*  5699 */ "pkcs-cipher\0"
/*  5711 */ "Specify the PKCS #11 provider library\0"
/*  5749 */ "PROVIDER\0"
/*  5758 */ "provider\0"
/*  5767 */ "display extended usage information and exit\0"
/*  5811 */ "help\0"
/*  5816 */ "extended usage information passed thru pager\0"
/*  5861 */ "more-help\0"
/*  5871 */ "output version information and exit\0"
/*  5907 */ "version\0"
/*  5915 */ "CERTTOOL\0"
/*  5924 */ "certtool - GnuTLS certificate tool\n"
            "Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n\0"
/*  6017 */ "bugs@gnutls.org\0"
/*  6033 */ "\n\0"
/*  6035 */ "Tool to parse and generate X.509 certificates, requests and private keys.\n"
            "It can be used interactively or non interactively by specifying the\n"
            "template command line option.\n\n"
            "The tool accepts files or URLs supported by GnuTLS.  In case PIN is\n"
            "required for the URL access you can provide it using the environment\n"
            "variables GNUTLS_PIN and GNUTLS_SO_PIN.\n\0"
/*  6386 */ "certtool 3.4.15\0"
/*  6402 */ "certtool [options]\n"
            "certtool --help for usage instructions.\n";

/**
 *  debug option description:
 */
/** Descriptive text for the debug option */
#define DEBUG_DESC      (certtool_opt_strs+889)
/** Upper-cased name for the debug option */
#define DEBUG_NAME      (certtool_opt_strs+906)
/** Name string for the debug option */
#define DEBUG_name      (certtool_opt_strs+912)
/** Compiled in flag settings for the debug option */
#define DEBUG_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  verbose option description:
 */
/** Descriptive text for the verbose option */
#define VERBOSE_DESC      (certtool_opt_strs+918)
/** Upper-cased name for the verbose option */
#define VERBOSE_NAME      (certtool_opt_strs+938)
/** Name string for the verbose option */
#define VERBOSE_name      (certtool_opt_strs+946)
/** Compiled in flag settings for the verbose option */
#define VERBOSE_FLAGS     (OPTST_DISABLED)

/**
 *  infile option description:
 */
/** Descriptive text for the infile option */
#define INFILE_DESC      (certtool_opt_strs+954)
/** Upper-cased name for the infile option */
#define INFILE_NAME      (certtool_opt_strs+965)
/** Name string for the infile option */
#define INFILE_name      (certtool_opt_strs+972)
/** Compiled in flag settings for the infile option */
#define INFILE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  outfile option description:
 */
/** Descriptive text for the outfile option */
#define OUTFILE_DESC      (certtool_opt_strs+979)
/** Upper-cased name for the outfile option */
#define OUTFILE_NAME      (certtool_opt_strs+991)
/** Name string for the outfile option */
#define OUTFILE_name      (certtool_opt_strs+999)
/** Compiled in flag settings for the outfile option */
#define OUTFILE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  generate-self-signed option description:
 */
/** Descriptive text for the generate-self-signed option */
#define GENERATE_SELF_SIGNED_DESC      (certtool_opt_strs+1007)
/** Upper-cased name for the generate-self-signed option */
#define GENERATE_SELF_SIGNED_NAME      (certtool_opt_strs+1042)
/** Name string for the generate-self-signed option */
#define GENERATE_SELF_SIGNED_name      (certtool_opt_strs+1063)
/** Compiled in flag settings for the generate-self-signed option */
#define GENERATE_SELF_SIGNED_FLAGS     (OPTST_DISABLED)

/**
 *  generate-certificate option description:
 */
/** Descriptive text for the generate-certificate option */
#define GENERATE_CERTIFICATE_DESC      (certtool_opt_strs+1084)
/** Upper-cased name for the generate-certificate option */
#define GENERATE_CERTIFICATE_NAME      (certtool_opt_strs+1114)
/** Name string for the generate-certificate option */
#define GENERATE_CERTIFICATE_name      (certtool_opt_strs+1135)
/** Compiled in flag settings for the generate-certificate option */
#define GENERATE_CERTIFICATE_FLAGS     (OPTST_DISABLED)

/**
 *  generate-proxy option description:
 */
/** Descriptive text for the generate-proxy option */
#define GENERATE_PROXY_DESC      (certtool_opt_strs+1156)
/** Upper-cased name for the generate-proxy option */
#define GENERATE_PROXY_NAME      (certtool_opt_strs+1186)
/** Name string for the generate-proxy option */
#define GENERATE_PROXY_name      (certtool_opt_strs+1201)
/** Compiled in flag settings for the generate-proxy option */
#define GENERATE_PROXY_FLAGS     (OPTST_DISABLED)

/**
 *  generate-crl option description:
 */
/** Descriptive text for the generate-crl option */
#define GENERATE_CRL_DESC      (certtool_opt_strs+1216)
/** Upper-cased name for the generate-crl option */
#define GENERATE_CRL_NAME      (certtool_opt_strs+1231)
/** Name string for the generate-crl option */
#define GENERATE_CRL_name      (certtool_opt_strs+1244)
/** Compiled in flag settings for the generate-crl option */
#define GENERATE_CRL_FLAGS     (OPTST_DISABLED)

/**
 *  update-certificate option description:
 */
/** Descriptive text for the update-certificate option */
#define UPDATE_CERTIFICATE_DESC      (certtool_opt_strs+1257)
/** Upper-cased name for the update-certificate option */
#define UPDATE_CERTIFICATE_NAME      (certtool_opt_strs+1285)
/** Name string for the update-certificate option */
#define UPDATE_CERTIFICATE_name      (certtool_opt_strs+1304)
/** Compiled in flag settings for the update-certificate option */
#define UPDATE_CERTIFICATE_FLAGS     (OPTST_DISABLED)

/**
 *  generate-privkey option description:
 */
/** Descriptive text for the generate-privkey option */
#define GENERATE_PRIVKEY_DESC      (certtool_opt_strs+1323)
/** Upper-cased name for the generate-privkey option */
#define GENERATE_PRIVKEY_NAME      (certtool_opt_strs+1346)
/** Name string for the generate-privkey option */
#define GENERATE_PRIVKEY_name      (certtool_opt_strs+1363)
/** Compiled in flag settings for the generate-privkey option */
#define GENERATE_PRIVKEY_FLAGS     (OPTST_DISABLED)

/**
 *  generate-request option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the generate-request option */
#define GENERATE_REQUEST_DESC      (certtool_opt_strs+1380)
/** Upper-cased name for the generate-request option */
#define GENERATE_REQUEST_NAME      (certtool_opt_strs+1420)
/** Name string for the generate-request option */
#define GENERATE_REQUEST_name      (certtool_opt_strs+1437)
/** Other options that appear in conjunction with the generate-request option */
static int const aGenerate_RequestCantList[] = {
    INDEX_OPT_INFILE, NO_EQUIVALENT };
/** Compiled in flag settings for the generate-request option */
#define GENERATE_REQUEST_FLAGS     (OPTST_DISABLED)

/**
 *  verify-chain option description:
 */
/** Descriptive text for the verify-chain option */
#define VERIFY_CHAIN_DESC      (certtool_opt_strs+1454)
/** Upper-cased name for the verify-chain option */
#define VERIFY_CHAIN_NAME      (certtool_opt_strs+1493)
/** Name string for the verify-chain option */
#define VERIFY_CHAIN_name      (certtool_opt_strs+1506)
/** Compiled in flag settings for the verify-chain option */
#define VERIFY_CHAIN_FLAGS     (OPTST_DISABLED)

/**
 *  verify option description:
 */
/** Descriptive text for the verify option */
#define VERIFY_DESC      (certtool_opt_strs+1519)
/** Upper-cased name for the verify option */
#define VERIFY_NAME      (certtool_opt_strs+1579)
/** Name string for the verify option */
#define VERIFY_name      (certtool_opt_strs+1586)
/** Compiled in flag settings for the verify option */
#define VERIFY_FLAGS     (OPTST_DISABLED)

/**
 *  verify-crl option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the verify-crl option */
#define VERIFY_CRL_DESC      (certtool_opt_strs+1593)
/** Upper-cased name for the verify-crl option */
#define VERIFY_CRL_NAME      (certtool_opt_strs+1627)
/** Name string for the verify-crl option */
#define VERIFY_CRL_name      (certtool_opt_strs+1638)
/** Other options that are required by the verify-crl option */
static int const aVerify_CrlMustList[] = {
    INDEX_OPT_LOAD_CA_CERTIFICATE, NO_EQUIVALENT };
/** Compiled in flag settings for the verify-crl option */
#define VERIFY_CRL_FLAGS     (OPTST_DISABLED)

/**
 *  verify-hostname option description:
 */
/** Descriptive text for the verify-hostname option */
#define VERIFY_HOSTNAME_DESC      (certtool_opt_strs+1649)
/** Upper-cased name for the verify-hostname option */
#define VERIFY_HOSTNAME_NAME      (certtool_opt_strs+1714)
/** Name string for the verify-hostname option */
#define VERIFY_HOSTNAME_name      (certtool_opt_strs+1730)
/** Compiled in flag settings for the verify-hostname option */
#define VERIFY_HOSTNAME_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  verify-email option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the verify-email option */
#define VERIFY_EMAIL_DESC      (certtool_opt_strs+1746)
/** Upper-cased name for the verify-email option */
#define VERIFY_EMAIL_NAME      (certtool_opt_strs+1808)
/** Name string for the verify-email option */
#define VERIFY_EMAIL_name      (certtool_opt_strs+1821)
/** Other options that appear in conjunction with the verify-email option */
static int const aVerify_EmailCantList[] = {
    INDEX_OPT_VERIFY_HOSTNAME, NO_EQUIVALENT };
/** Compiled in flag settings for the verify-email option */
#define VERIFY_EMAIL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  verify-purpose option description:
 */
/** Descriptive text for the verify-purpose option */
#define VERIFY_PURPOSE_DESC      (certtool_opt_strs+1834)
/** Upper-cased name for the verify-purpose option */
#define VERIFY_PURPOSE_NAME      (certtool_opt_strs+1902)
/** Name string for the verify-purpose option */
#define VERIFY_PURPOSE_name      (certtool_opt_strs+1917)
/** Compiled in flag settings for the verify-purpose option */
#define VERIFY_PURPOSE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  generate-dh-params option description:
 */
/** Descriptive text for the generate-dh-params option */
#define GENERATE_DH_PARAMS_DESC      (certtool_opt_strs+1932)
/** Upper-cased name for the generate-dh-params option */
#define GENERATE_DH_PARAMS_NAME      (certtool_opt_strs+1983)
/** Name string for the generate-dh-params option */
#define GENERATE_DH_PARAMS_name      (certtool_opt_strs+2002)
/** Compiled in flag settings for the generate-dh-params option */
#define GENERATE_DH_PARAMS_FLAGS     (OPTST_DISABLED)

/**
 *  get-dh-params option description:
 */
/** Descriptive text for the get-dh-params option */
#define GET_DH_PARAMS_DESC      (certtool_opt_strs+2021)
/** Upper-cased name for the get-dh-params option */
#define GET_DH_PARAMS_NAME      (certtool_opt_strs+2080)
/** Name string for the get-dh-params option */
#define GET_DH_PARAMS_name      (certtool_opt_strs+2094)
/** Compiled in flag settings for the get-dh-params option */
#define GET_DH_PARAMS_FLAGS     (OPTST_DISABLED)

/**
 *  dh-info option description:
 */
/** Descriptive text for the dh-info option */
#define DH_INFO_DESC      (certtool_opt_strs+2108)
/** Upper-cased name for the dh-info option */
#define DH_INFO_NAME      (certtool_opt_strs+2168)
/** Name string for the dh-info option */
#define DH_INFO_name      (certtool_opt_strs+2176)
/** Compiled in flag settings for the dh-info option */
#define DH_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  load-privkey option description:
 */
/** Descriptive text for the load-privkey option */
#define LOAD_PRIVKEY_DESC      (certtool_opt_strs+2184)
/** Upper-cased name for the load-privkey option */
#define LOAD_PRIVKEY_NAME      (certtool_opt_strs+2209)
/** Name string for the load-privkey option */
#define LOAD_PRIVKEY_name      (certtool_opt_strs+2222)
/** Compiled in flag settings for the load-privkey option */
#define LOAD_PRIVKEY_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  load-pubkey option description:
 */
/** Descriptive text for the load-pubkey option */
#define LOAD_PUBKEY_DESC      (certtool_opt_strs+2235)
/** Upper-cased name for the load-pubkey option */
#define LOAD_PUBKEY_NAME      (certtool_opt_strs+2259)
/** Name string for the load-pubkey option */
#define LOAD_PUBKEY_name      (certtool_opt_strs+2271)
/** Compiled in flag settings for the load-pubkey option */
#define LOAD_PUBKEY_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  load-request option description:
 */
/** Descriptive text for the load-request option */
#define LOAD_REQUEST_DESC      (certtool_opt_strs+2283)
/** Upper-cased name for the load-request option */
#define LOAD_REQUEST_NAME      (certtool_opt_strs+2316)
/** Name string for the load-request option */
#define LOAD_REQUEST_name      (certtool_opt_strs+2329)
/** Compiled in flag settings for the load-request option */
#define LOAD_REQUEST_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  load-certificate option description:
 */
/** Descriptive text for the load-certificate option */
#define LOAD_CERTIFICATE_DESC      (certtool_opt_strs+2342)
/** Upper-cased name for the load-certificate option */
#define LOAD_CERTIFICATE_NAME      (certtool_opt_strs+2367)
/** Name string for the load-certificate option */
#define LOAD_CERTIFICATE_name      (certtool_opt_strs+2384)
/** Compiled in flag settings for the load-certificate option */
#define LOAD_CERTIFICATE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  load-ca-privkey option description:
 */
/** Descriptive text for the load-ca-privkey option */
#define LOAD_CA_PRIVKEY_DESC      (certtool_opt_strs+2401)
/** Upper-cased name for the load-ca-privkey option */
#define LOAD_CA_PRIVKEY_NAME      (certtool_opt_strs+2452)
/** Name string for the load-ca-privkey option */
#define LOAD_CA_PRIVKEY_name      (certtool_opt_strs+2468)
/** Compiled in flag settings for the load-ca-privkey option */
#define LOAD_CA_PRIVKEY_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  load-ca-certificate option description:
 */
/** Descriptive text for the load-ca-certificate option */
#define LOAD_CA_CERTIFICATE_DESC      (certtool_opt_strs+2484)
/** Upper-cased name for the load-ca-certificate option */
#define LOAD_CA_CERTIFICATE_NAME      (certtool_opt_strs+2535)
/** Name string for the load-ca-certificate option */
#define LOAD_CA_CERTIFICATE_name      (certtool_opt_strs+2555)
/** Compiled in flag settings for the load-ca-certificate option */
#define LOAD_CA_CERTIFICATE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  load-crl option description:
 */
/** Descriptive text for the load-crl option */
#define LOAD_CRL_DESC      (certtool_opt_strs+2575)
/** Upper-cased name for the load-crl option */
#define LOAD_CRL_NAME      (certtool_opt_strs+2598)
/** Name string for the load-crl option */
#define LOAD_CRL_name      (certtool_opt_strs+2607)
/** Compiled in flag settings for the load-crl option */
#define LOAD_CRL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  load-data option description:
 */
/** Descriptive text for the load-data option */
#define LOAD_DATA_DESC      (certtool_opt_strs+2616)
/** Upper-cased name for the load-data option */
#define LOAD_DATA_NAME      (certtool_opt_strs+2636)
/** Name string for the load-data option */
#define LOAD_DATA_name      (certtool_opt_strs+2646)
/** Compiled in flag settings for the load-data option */
#define LOAD_DATA_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  password option description:
 */
/** Descriptive text for the password option */
#define PASSWORD_DESC      (certtool_opt_strs+2656)
/** Upper-cased name for the password option */
#define PASSWORD_NAME      (certtool_opt_strs+2672)
/** Name string for the password option */
#define PASSWORD_name      (certtool_opt_strs+2681)
/** Compiled in flag settings for the password option */
#define PASSWORD_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  null-password option description:
 */
/** Descriptive text for the null-password option */
#define NULL_PASSWORD_DESC      (certtool_opt_strs+2690)
/** Upper-cased name for the null-password option */
#define NULL_PASSWORD_NAME      (certtool_opt_strs+2714)
/** Name string for the null-password option */
#define NULL_PASSWORD_name      (certtool_opt_strs+2728)
/** Compiled in flag settings for the null-password option */
#define NULL_PASSWORD_FLAGS     (OPTST_DISABLED)

/**
 *  empty-password option description:
 */
/** Descriptive text for the empty-password option */
#define EMPTY_PASSWORD_DESC      (certtool_opt_strs+2742)
/** Upper-cased name for the empty-password option */
#define EMPTY_PASSWORD_NAME      (certtool_opt_strs+2768)
/** Name string for the empty-password option */
#define EMPTY_PASSWORD_name      (certtool_opt_strs+2783)
/** Compiled in flag settings for the empty-password option */
#define EMPTY_PASSWORD_FLAGS     (OPTST_DISABLED)

/**
 *  hex-numbers option description:
 */
/** Descriptive text for the hex-numbers option */
#define HEX_NUMBERS_DESC      (certtool_opt_strs+2798)
/** Upper-cased name for the hex-numbers option */
#define HEX_NUMBERS_NAME      (certtool_opt_strs+2844)
/** Name string for the hex-numbers option */
#define HEX_NUMBERS_name      (certtool_opt_strs+2856)
/** Compiled in flag settings for the hex-numbers option */
#define HEX_NUMBERS_FLAGS     (OPTST_DISABLED)

/**
 *  cprint option description:
 */
/** Descriptive text for the cprint option */
#define CPRINT_DESC      (certtool_opt_strs+2868)
/** Upper-cased name for the cprint option */
#define CPRINT_NAME      (certtool_opt_strs+2937)
/** Name string for the cprint option */
#define CPRINT_name      (certtool_opt_strs+2944)
/** Compiled in flag settings for the cprint option */
#define CPRINT_FLAGS     (OPTST_DISABLED)

/**
 *  certificate-info option description:
 */
/** Descriptive text for the certificate-info option */
#define CERTIFICATE_INFO_DESC      (certtool_opt_strs+2951)
/** Upper-cased name for the certificate-info option */
#define CERTIFICATE_INFO_NAME      (certtool_opt_strs+2994)
/** Name string for the certificate-info option */
#define CERTIFICATE_INFO_name      (certtool_opt_strs+3011)
/** Compiled in flag settings for the certificate-info option */
#define CERTIFICATE_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  fingerprint option description:
 */
/** Descriptive text for the fingerprint option */
#define FINGERPRINT_DESC      (certtool_opt_strs+3028)
/** Upper-cased name for the fingerprint option */
#define FINGERPRINT_NAME      (certtool_opt_strs+3075)
/** Name string for the fingerprint option */
#define FINGERPRINT_name      (certtool_opt_strs+3087)
/** Compiled in flag settings for the fingerprint option */
#define FINGERPRINT_FLAGS     (OPTST_DISABLED)

/**
 *  key-id option description:
 */
/** Descriptive text for the key-id option */
#define KEY_ID_DESC      (certtool_opt_strs+3099)
/** Upper-cased name for the key-id option */
#define KEY_ID_NAME      (certtool_opt_strs+3141)
/** Name string for the key-id option */
#define KEY_ID_name      (certtool_opt_strs+3148)
/** Compiled in flag settings for the key-id option */
#define KEY_ID_FLAGS     (OPTST_DISABLED)

/**
 *  certificate-pubkey option description:
 */
/** Descriptive text for the certificate-pubkey option */
#define CERTIFICATE_PUBKEY_DESC      (certtool_opt_strs+3155)
/** Upper-cased name for the certificate-pubkey option */
#define CERTIFICATE_PUBKEY_NAME      (certtool_opt_strs+3186)
/** Name string for the certificate-pubkey option */
#define CERTIFICATE_PUBKEY_name      (certtool_opt_strs+3205)
/** Compiled in flag settings for the certificate-pubkey option */
#define CERTIFICATE_PUBKEY_FLAGS     (OPTST_DISABLED)

/**
 *  pgp-certificate-info option description:
 */
/** Descriptive text for the pgp-certificate-info option */
#define PGP_CERTIFICATE_INFO_DESC      (certtool_opt_strs+3224)
/** Upper-cased name for the pgp-certificate-info option */
#define PGP_CERTIFICATE_INFO_NAME      (certtool_opt_strs+3275)
/** Name string for the pgp-certificate-info option */
#define PGP_CERTIFICATE_INFO_name      (certtool_opt_strs+3296)
/** Compiled in flag settings for the pgp-certificate-info option */
#define PGP_CERTIFICATE_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  pgp-ring-info option description:
 */
/** Descriptive text for the pgp-ring-info option */
#define PGP_RING_INFO_DESC      (certtool_opt_strs+3317)
/** Upper-cased name for the pgp-ring-info option */
#define PGP_RING_INFO_NAME      (certtool_opt_strs+3374)
/** Name string for the pgp-ring-info option */
#define PGP_RING_INFO_name      (certtool_opt_strs+3388)
/** Compiled in flag settings for the pgp-ring-info option */
#define PGP_RING_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  crl-info option description:
 */
/** Descriptive text for the crl-info option */
#define CRL_INFO_DESC      (certtool_opt_strs+3402)
/** Upper-cased name for the crl-info option */
#define CRL_INFO_NAME      (certtool_opt_strs+3447)
/** Name string for the crl-info option */
#define CRL_INFO_name      (certtool_opt_strs+3456)
/** Compiled in flag settings for the crl-info option */
#define CRL_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  crq-info option description:
 */
/** Descriptive text for the crq-info option */
#define CRQ_INFO_DESC      (certtool_opt_strs+3465)
/** Upper-cased name for the crq-info option */
#define CRQ_INFO_NAME      (certtool_opt_strs+3516)
/** Name string for the crq-info option */
#define CRQ_INFO_name      (certtool_opt_strs+3525)
/** Compiled in flag settings for the crq-info option */
#define CRQ_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  no-crq-extensions option description:
 */
/** Descriptive text for the no-crq-extensions option */
#define NO_CRQ_EXTENSIONS_DESC      (certtool_opt_strs+3534)
/** Upper-cased name for the no-crq-extensions option */
#define NO_CRQ_EXTENSIONS_NAME      (certtool_opt_strs+3580)
/** Name string for the no-crq-extensions option */
#define NO_CRQ_EXTENSIONS_name      (certtool_opt_strs+3598)
/** Compiled in flag settings for the no-crq-extensions option */
#define NO_CRQ_EXTENSIONS_FLAGS     (OPTST_DISABLED)

/**
 *  p12-info option description:
 */
/** Descriptive text for the p12-info option */
#define P12_INFO_DESC      (certtool_opt_strs+3616)
/** Upper-cased name for the p12-info option */
#define P12_INFO_NAME      (certtool_opt_strs+3658)
/** Name string for the p12-info option */
#define P12_INFO_name      (certtool_opt_strs+3667)
/** Compiled in flag settings for the p12-info option */
#define P12_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  p12-name option description:
 */
/** Descriptive text for the p12-name option */
#define P12_NAME_DESC      (certtool_opt_strs+3676)
/** Upper-cased name for the p12-name option */
#define P12_NAME_NAME      (certtool_opt_strs+3710)
/** Name string for the p12-name option */
#define P12_NAME_name      (certtool_opt_strs+3719)
/** Compiled in flag settings for the p12-name option */
#define P12_NAME_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  p7-generate option description:
 */
/** Descriptive text for the p7-generate option */
#define P7_GENERATE_DESC      (certtool_opt_strs+3728)
/** Upper-cased name for the p7-generate option */
#define P7_GENERATE_NAME      (certtool_opt_strs+3757)
/** Name string for the p7-generate option */
#define P7_GENERATE_name      (certtool_opt_strs+3769)
/** Compiled in flag settings for the p7-generate option */
#define P7_GENERATE_FLAGS     (OPTST_DISABLED)

/**
 *  p7-sign option description:
 */
/** Descriptive text for the p7-sign option */
#define P7_SIGN_DESC      (certtool_opt_strs+3781)
/** Upper-cased name for the p7-sign option */
#define P7_SIGN_NAME      (certtool_opt_strs+3813)
/** Name string for the p7-sign option */
#define P7_SIGN_name      (certtool_opt_strs+3821)
/** Compiled in flag settings for the p7-sign option */
#define P7_SIGN_FLAGS     (OPTST_DISABLED)

/**
 *  p7-detached-sign option description:
 */
/** Descriptive text for the p7-detached-sign option */
#define P7_DETACHED_SIGN_DESC      (certtool_opt_strs+3829)
/** Upper-cased name for the p7-detached-sign option */
#define P7_DETACHED_SIGN_NAME      (certtool_opt_strs+3870)
/** Name string for the p7-detached-sign option */
#define P7_DETACHED_SIGN_name      (certtool_opt_strs+3887)
/** Compiled in flag settings for the p7-detached-sign option */
#define P7_DETACHED_SIGN_FLAGS     (OPTST_DISABLED)

/**
 *  p7-include-cert option description:
 */
/** Descriptive text for the p7-include-cert option */
#define P7_INCLUDE_CERT_DESC      (certtool_opt_strs+3904)
/** Upper-cased name for the p7-include-cert option */
#define P7_INCLUDE_CERT_NAME      (certtool_opt_strs+3964)
/** disablement name for the p7-include-cert option */
#define NOT_P7_INCLUDE_CERT_name  (certtool_opt_strs+3980)
/** disablement prefix for the p7-include-cert option */
#define NOT_P7_INCLUDE_CERT_PFX   (certtool_opt_strs+3999)
/** Name string for the p7-include-cert option */
#define P7_INCLUDE_CERT_name      (NOT_P7_INCLUDE_CERT_name + 3)
/** Compiled in flag settings for the p7-include-cert option */
#define P7_INCLUDE_CERT_FLAGS     (OPTST_INITENABLED)

/**
 *  p7-time option description:
 */
/** Descriptive text for the p7-time option */
#define P7_TIME_DESC      (certtool_opt_strs+4002)
/** Upper-cased name for the p7-time option */
#define P7_TIME_NAME      (certtool_opt_strs+4052)
/** Name string for the p7-time option */
#define P7_TIME_name      (certtool_opt_strs+4060)
/** Compiled in flag settings for the p7-time option */
#define P7_TIME_FLAGS     (OPTST_DISABLED)

/**
 *  p7-show-data option description:
 */
/** Descriptive text for the p7-show-data option */
#define P7_SHOW_DATA_DESC      (certtool_opt_strs+4068)
/** Upper-cased name for the p7-show-data option */
#define P7_SHOW_DATA_NAME      (certtool_opt_strs+4121)
/** disablement name for the p7-show-data option */
#define NOT_P7_SHOW_DATA_name  (certtool_opt_strs+4134)
/** disablement prefix for the p7-show-data option */
#define NOT_P7_SHOW_DATA_PFX   (certtool_opt_strs+3999)
/** Name string for the p7-show-data option */
#define P7_SHOW_DATA_name      (NOT_P7_SHOW_DATA_name + 3)
/** Compiled in flag settings for the p7-show-data option */
#define P7_SHOW_DATA_FLAGS     (OPTST_DISABLED)

/**
 *  p7-info option description:
 */
/** Descriptive text for the p7-info option */
#define P7_INFO_DESC      (certtool_opt_strs+4150)
/** Upper-cased name for the p7-info option */
#define P7_INFO_NAME      (certtool_opt_strs+4191)
/** Name string for the p7-info option */
#define P7_INFO_name      (certtool_opt_strs+4199)
/** Compiled in flag settings for the p7-info option */
#define P7_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  p7-verify option description:
 */
/** Descriptive text for the p7-verify option */
#define P7_VERIFY_DESC      (certtool_opt_strs+4207)
/** Upper-cased name for the p7-verify option */
#define P7_VERIFY_NAME      (certtool_opt_strs+4245)
/** Name string for the p7-verify option */
#define P7_VERIFY_name      (certtool_opt_strs+4255)
/** Compiled in flag settings for the p7-verify option */
#define P7_VERIFY_FLAGS     (OPTST_DISABLED)

/**
 *  p8-info option description:
 */
/** Descriptive text for the p8-info option */
#define P8_INFO_DESC      (certtool_opt_strs+4265)
/** Upper-cased name for the p8-info option */
#define P8_INFO_NAME      (certtool_opt_strs+4306)
/** Name string for the p8-info option */
#define P8_INFO_name      (certtool_opt_strs+4314)
/** Compiled in flag settings for the p8-info option */
#define P8_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  smime-to-p7 option description:
 */
/** Descriptive text for the smime-to-p7 option */
#define SMIME_TO_P7_DESC      (certtool_opt_strs+4322)
/** Upper-cased name for the smime-to-p7 option */
#define SMIME_TO_P7_NAME      (certtool_opt_strs+4358)
/** Name string for the smime-to-p7 option */
#define SMIME_TO_P7_name      (certtool_opt_strs+4370)
/** Compiled in flag settings for the smime-to-p7 option */
#define SMIME_TO_P7_FLAGS     (OPTST_DISABLED)

/**
 *  key-info option description:
 */
/** Descriptive text for the key-info option */
#define KEY_INFO_DESC      (certtool_opt_strs+4382)
/** Upper-cased name for the key-info option */
#define KEY_INFO_NAME      (certtool_opt_strs+4417)
/** Name string for the key-info option */
#define KEY_INFO_name      (certtool_opt_strs+4426)
/** Compiled in flag settings for the key-info option */
#define KEY_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  pgp-key-info option description:
 */
/** Descriptive text for the pgp-key-info option */
#define PGP_KEY_INFO_DESC      (certtool_opt_strs+4435)
/** Upper-cased name for the pgp-key-info option */
#define PGP_KEY_INFO_NAME      (certtool_opt_strs+4479)
/** Name string for the pgp-key-info option */
#define PGP_KEY_INFO_name      (certtool_opt_strs+4492)
/** Compiled in flag settings for the pgp-key-info option */
#define PGP_KEY_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  pubkey-info option description:
 */
/** Descriptive text for the pubkey-info option */
#define PUBKEY_INFO_DESC      (certtool_opt_strs+4505)
/** Upper-cased name for the pubkey-info option */
#define PUBKEY_INFO_NAME      (certtool_opt_strs+4539)
/** Name string for the pubkey-info option */
#define PUBKEY_INFO_name      (certtool_opt_strs+4551)
/** Compiled in flag settings for the pubkey-info option */
#define PUBKEY_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  v1 option description:
 */
/** Descriptive text for the v1 option */
#define V1_DESC      (certtool_opt_strs+4563)
/** Upper-cased name for the v1 option */
#define V1_NAME      (certtool_opt_strs+4624)
/** Name string for the v1 option */
#define V1_name      (certtool_opt_strs+4627)
/** Compiled in flag settings for the v1 option */
#define V1_FLAGS     (OPTST_DISABLED)

/**
 *  to-p12 option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the to-p12 option */
#define TO_P12_DESC      (certtool_opt_strs+4630)
/** Upper-cased name for the to-p12 option */
#define TO_P12_NAME      (certtool_opt_strs+4660)
/** Name string for the to-p12 option */
#define TO_P12_name      (certtool_opt_strs+4667)
/** Other options that are required by the to-p12 option */
static int const aTo_P12MustList[] = {
    INDEX_OPT_LOAD_CERTIFICATE, NO_EQUIVALENT };
/** Compiled in flag settings for the to-p12 option */
#define TO_P12_FLAGS     (OPTST_DISABLED)

/**
 *  to-p8 option description:
 */
/** Descriptive text for the to-p8 option */
#define TO_P8_DESC      (certtool_opt_strs+4674)
/** Upper-cased name for the to-p8 option */
#define TO_P8_NAME      (certtool_opt_strs+4703)
/** Name string for the to-p8 option */
#define TO_P8_name      (certtool_opt_strs+4709)
/** Compiled in flag settings for the to-p8 option */
#define TO_P8_FLAGS     (OPTST_DISABLED)

/**
 *  pkcs8 option description:
 */
/** Descriptive text for the pkcs8 option */
#define PKCS8_DESC      (certtool_opt_strs+4715)
/** Upper-cased name for the pkcs8 option */
#define PKCS8_NAME      (certtool_opt_strs+4751)
/** Name string for the pkcs8 option */
#define PKCS8_name      (certtool_opt_strs+4757)
/** Compiled in flag settings for the pkcs8 option */
#define PKCS8_FLAGS     (OPTST_DISABLED)

/**
 *  rsa option description:
 */
/** Descriptive text for the rsa option */
#define RSA_DESC      (certtool_opt_strs+4763)
/** Upper-cased name for the rsa option */
#define RSA_NAME      (certtool_opt_strs+4780)
/** Name string for the rsa option */
#define RSA_name      (certtool_opt_strs+4784)
/** Compiled in flag settings for the rsa option */
#define RSA_FLAGS     (OPTST_DISABLED)

/**
 *  dsa option description:
 */
/** Descriptive text for the dsa option */
#define DSA_DESC      (certtool_opt_strs+4788)
/** Upper-cased name for the dsa option */
#define DSA_NAME      (certtool_opt_strs+4805)
/** Name string for the dsa option */
#define DSA_name      (certtool_opt_strs+4809)
/** Compiled in flag settings for the dsa option */
#define DSA_FLAGS     (OPTST_DISABLED)

/**
 *  ecc option description:
 */
/** Descriptive text for the ecc option */
#define ECC_DESC      (certtool_opt_strs+4813)
/** Upper-cased name for the ecc option */
#define ECC_NAME      (certtool_opt_strs+4838)
/** Name string for the ecc option */
#define ECC_name      (certtool_opt_strs+4842)
/** Compiled in flag settings for the ecc option */
#define ECC_FLAGS     (OPTST_DISABLED)

/**
 *  ecdsa option description:
 */
/** Descriptive text for the ecdsa option */
#define ECDSA_DESC    (certtool_opt_strs+4846)
#define ECDSA_NAME    NULL
/** Unmodified name string for the ecdsa option */
#define ECDSA_name    (certtool_opt_strs+4876)
/** Compiled in flag settings for the ecdsa option */
#define ECDSA_FLAGS     (ECC_FLAGS | OPTST_ALIAS)

/**
 *  hash option description:
 */
/** Descriptive text for the hash option */
#define HASH_DESC      (certtool_opt_strs+4882)
/** Upper-cased name for the hash option */
#define HASH_NAME      (certtool_opt_strs+4916)
/** Name string for the hash option */
#define HASH_name      (certtool_opt_strs+4921)
/** Compiled in flag settings for the hash option */
#define HASH_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  inder option description:
 */
/** Descriptive text for the inder option */
#define INDER_DESC      (certtool_opt_strs+4926)
/** Upper-cased name for the inder option */
#define INDER_NAME      (certtool_opt_strs+4997)
/** disablement name for the inder option */
#define NOT_INDER_name  (certtool_opt_strs+5003)
/** disablement prefix for the inder option */
#define NOT_INDER_PFX   (certtool_opt_strs+3999)
/** Name string for the inder option */
#define INDER_name      (NOT_INDER_name + 3)
/** Compiled in flag settings for the inder option */
#define INDER_FLAGS     (OPTST_DISABLED)

/**
 *  inraw option description:
 */
/** Descriptive text for the inraw option */
#define INRAW_DESC    (certtool_opt_strs+5012)
#define INRAW_NAME    NULL
/** Unmodified name string for the inraw option */
#define INRAW_name    (certtool_opt_strs+5044)
/** Compiled in flag settings for the inraw option */
#define INRAW_FLAGS     (INDER_FLAGS | OPTST_ALIAS)

/**
 *  outder option description:
 */
/** Descriptive text for the outder option */
#define OUTDER_DESC      (certtool_opt_strs+5050)
/** Upper-cased name for the outder option */
#define OUTDER_NAME      (certtool_opt_strs+5122)
/** disablement name for the outder option */
#define NOT_OUTDER_name  (certtool_opt_strs+5129)
/** disablement prefix for the outder option */
#define NOT_OUTDER_PFX   (certtool_opt_strs+3999)
/** Name string for the outder option */
#define OUTDER_name      (NOT_OUTDER_name + 3)
/** Compiled in flag settings for the outder option */
#define OUTDER_FLAGS     (OPTST_DISABLED)

/**
 *  outraw option description:
 */
/** Descriptive text for the outraw option */
#define OUTRAW_DESC    (certtool_opt_strs+5139)
#define OUTRAW_NAME    NULL
/** Unmodified name string for the outraw option */
#define OUTRAW_name    (certtool_opt_strs+5172)
/** Compiled in flag settings for the outraw option */
#define OUTRAW_FLAGS     (OUTDER_FLAGS | OPTST_ALIAS)

/**
 *  bits option description:
 */
/** Descriptive text for the bits option */
#define BITS_DESC      (certtool_opt_strs+5179)
/** Upper-cased name for the bits option */
#define BITS_NAME      (certtool_opt_strs+5223)
/** Name string for the bits option */
#define BITS_name      (certtool_opt_strs+5228)
/** Compiled in flag settings for the bits option */
#define BITS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  curve option description:
 */
/** Descriptive text for the curve option */
#define CURVE_DESC      (certtool_opt_strs+5233)
/** Upper-cased name for the curve option */
#define CURVE_NAME      (certtool_opt_strs+5278)
/** Name string for the curve option */
#define CURVE_name      (certtool_opt_strs+5284)
/** Compiled in flag settings for the curve option */
#define CURVE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  sec-param option description:
 */
/** Descriptive text for the sec-param option */
#define SEC_PARAM_DESC      (certtool_opt_strs+5290)
/** Upper-cased name for the sec-param option */
#define SEC_PARAM_NAME      (certtool_opt_strs+5352)
/** Name string for the sec-param option */
#define SEC_PARAM_name      (certtool_opt_strs+5362)
/** Compiled in flag settings for the sec-param option */
#define SEC_PARAM_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  disable-quick-random option description:
 */
/** Descriptive text for the disable-quick-random option */
#define DISABLE_QUICK_RANDOM_DESC      (certtool_opt_strs+5372)
/** Upper-cased name for the disable-quick-random option */
#define DISABLE_QUICK_RANDOM_NAME      (certtool_opt_strs+5382)
/** Name string for the disable-quick-random option */
#define DISABLE_QUICK_RANDOM_name      (certtool_opt_strs+5403)
/** Compiled in flag settings for the disable-quick-random option */
#define DISABLE_QUICK_RANDOM_FLAGS     (OPTST_DISABLED)

/**
 *  template option description:
 */
/** Descriptive text for the template option */
#define TEMPLATE_DESC      (certtool_opt_strs+5424)
/** Upper-cased name for the template option */
#define TEMPLATE_NAME      (certtool_opt_strs+5475)
/** Name string for the template option */
#define TEMPLATE_name      (certtool_opt_strs+5484)
/** Compiled in flag settings for the template option */
#define TEMPLATE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  stdout-info option description:
 */
/** Descriptive text for the stdout-info option */
#define STDOUT_INFO_DESC      (certtool_opt_strs+5493)
/** Upper-cased name for the stdout-info option */
#define STDOUT_INFO_NAME      (certtool_opt_strs+5539)
/** Name string for the stdout-info option */
#define STDOUT_INFO_name      (certtool_opt_strs+5551)
/** Compiled in flag settings for the stdout-info option */
#define STDOUT_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  ask-pass option description:
 */
/** Descriptive text for the ask-pass option */
#define ASK_PASS_DESC      (certtool_opt_strs+5563)
/** Upper-cased name for the ask-pass option */
#define ASK_PASS_NAME      (certtool_opt_strs+5624)
/** Name string for the ask-pass option */
#define ASK_PASS_name      (certtool_opt_strs+5633)
/** Compiled in flag settings for the ask-pass option */
#define ASK_PASS_FLAGS     (OPTST_DISABLED)

/**
 *  pkcs-cipher option description:
 */
/** Descriptive text for the pkcs-cipher option */
#define PKCS_CIPHER_DESC      (certtool_opt_strs+5642)
/** Upper-cased name for the pkcs-cipher option */
#define PKCS_CIPHER_NAME      (certtool_opt_strs+5687)
/** Name string for the pkcs-cipher option */
#define PKCS_CIPHER_name      (certtool_opt_strs+5699)
/** Compiled in flag settings for the pkcs-cipher option */
#define PKCS_CIPHER_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  provider option description:
 */
/** Descriptive text for the provider option */
#define PROVIDER_DESC      (certtool_opt_strs+5711)
/** Upper-cased name for the provider option */
#define PROVIDER_NAME      (certtool_opt_strs+5749)
/** Name string for the provider option */
#define PROVIDER_name      (certtool_opt_strs+5758)
/** Compiled in flag settings for the provider option */
#define PROVIDER_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/*
 *  Help/More_Help/Version option descriptions:
 */
#define HELP_DESC       (certtool_opt_strs+5767)
#define HELP_name       (certtool_opt_strs+5811)
#ifdef HAVE_WORKING_FORK
#define MORE_HELP_DESC  (certtool_opt_strs+5816)
#define MORE_HELP_name  (certtool_opt_strs+5861)
#define MORE_HELP_FLAGS (OPTST_IMM | OPTST_NO_INIT)
#else
#define MORE_HELP_DESC  HELP_DESC
#define MORE_HELP_name  HELP_name
#define MORE_HELP_FLAGS (OPTST_OMITTED | OPTST_NO_INIT)
#endif
#ifdef NO_OPTIONAL_OPT_ARGS
#  define VER_FLAGS     (OPTST_IMM | OPTST_NO_INIT)
#else
#  define VER_FLAGS     (OPTST_SET_ARGTYPE(OPARG_TYPE_STRING) | \
                         OPTST_ARG_OPTIONAL | OPTST_IMM | OPTST_NO_INIT)
#endif
#define VER_DESC        (certtool_opt_strs+5871)
#define VER_name        (certtool_opt_strs+5907)
/**
 *  Declare option callback procedures
 */
extern tOptProc
    optionBooleanVal,   optionNestedVal,    optionNumericVal,
    optionPagedUsage,   optionPrintVersion, optionResetOpt,
    optionStackArg,     optionTimeDate,     optionTimeVal,
    optionUnstackArg,   optionVendorOption;
static tOptProc
    doOptDebug,  doOptEcdsa,  doOptInfile, doOptInraw,  doOptOutraw,
    doUsageOpt;
#define VER_PROC        optionPrintVersion

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 *  Define the certtool Option Descriptions.
 * This is an array of OPTION_CT entries, one for each
 * option that the certtool program responds to.
 */
static tOptDesc optDesc[OPTION_CT] = {
  {  /* entry idx, value */ 0, VALUE_OPT_DEBUG,
     /* equiv idx, value */ 0, VALUE_OPT_DEBUG,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DEBUG_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --debug */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptDebug,
     /* desc, NAME, name */ DEBUG_DESC, DEBUG_NAME, DEBUG_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 1, VALUE_OPT_VERBOSE,
     /* equiv idx, value */ 1, VALUE_OPT_VERBOSE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, NOLIMIT, 0,
     /* opt state flags  */ VERBOSE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verbose */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERBOSE_DESC, VERBOSE_NAME, VERBOSE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 2, VALUE_OPT_INFILE,
     /* equiv idx, value */ 2, VALUE_OPT_INFILE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ INFILE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --infile */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptInfile,
     /* desc, NAME, name */ INFILE_DESC, INFILE_NAME, INFILE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 3, VALUE_OPT_OUTFILE,
     /* equiv idx, value */ 3, VALUE_OPT_OUTFILE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OUTFILE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --outfile */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ OUTFILE_DESC, OUTFILE_NAME, OUTFILE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 4, VALUE_OPT_GENERATE_SELF_SIGNED,
     /* equiv idx, value */ 4, VALUE_OPT_GENERATE_SELF_SIGNED,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_SELF_SIGNED_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-self-signed */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_SELF_SIGNED_DESC, GENERATE_SELF_SIGNED_NAME, GENERATE_SELF_SIGNED_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 5, VALUE_OPT_GENERATE_CERTIFICATE,
     /* equiv idx, value */ 5, VALUE_OPT_GENERATE_CERTIFICATE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_CERTIFICATE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-certificate */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_CERTIFICATE_DESC, GENERATE_CERTIFICATE_NAME, GENERATE_CERTIFICATE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 6, VALUE_OPT_GENERATE_PROXY,
     /* equiv idx, value */ 6, VALUE_OPT_GENERATE_PROXY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_PROXY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-proxy */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_PROXY_DESC, GENERATE_PROXY_NAME, GENERATE_PROXY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 7, VALUE_OPT_GENERATE_CRL,
     /* equiv idx, value */ 7, VALUE_OPT_GENERATE_CRL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_CRL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-crl */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_CRL_DESC, GENERATE_CRL_NAME, GENERATE_CRL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 8, VALUE_OPT_UPDATE_CERTIFICATE,
     /* equiv idx, value */ 8, VALUE_OPT_UPDATE_CERTIFICATE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ UPDATE_CERTIFICATE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --update-certificate */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ UPDATE_CERTIFICATE_DESC, UPDATE_CERTIFICATE_NAME, UPDATE_CERTIFICATE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 9, VALUE_OPT_GENERATE_PRIVKEY,
     /* equiv idx, value */ 9, VALUE_OPT_GENERATE_PRIVKEY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_PRIVKEY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-privkey */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_PRIVKEY_DESC, GENERATE_PRIVKEY_NAME, GENERATE_PRIVKEY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 10, VALUE_OPT_GENERATE_REQUEST,
     /* equiv idx, value */ 10, VALUE_OPT_GENERATE_REQUEST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_REQUEST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-request */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aGenerate_RequestCantList,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_REQUEST_DESC, GENERATE_REQUEST_NAME, GENERATE_REQUEST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 11, VALUE_OPT_VERIFY_CHAIN,
     /* equiv idx, value */ 11, VALUE_OPT_VERIFY_CHAIN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_CHAIN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify-chain */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_CHAIN_DESC, VERIFY_CHAIN_NAME, VERIFY_CHAIN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 12, VALUE_OPT_VERIFY,
     /* equiv idx, value */ 12, VALUE_OPT_VERIFY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_DESC, VERIFY_NAME, VERIFY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 13, VALUE_OPT_VERIFY_CRL,
     /* equiv idx, value */ 13, VALUE_OPT_VERIFY_CRL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_CRL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify-crl */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aVerify_CrlMustList, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_CRL_DESC, VERIFY_CRL_NAME, VERIFY_CRL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 14, VALUE_OPT_VERIFY_HOSTNAME,
     /* equiv idx, value */ 14, VALUE_OPT_VERIFY_HOSTNAME,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_HOSTNAME_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify-hostname */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_HOSTNAME_DESC, VERIFY_HOSTNAME_NAME, VERIFY_HOSTNAME_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 15, VALUE_OPT_VERIFY_EMAIL,
     /* equiv idx, value */ 15, VALUE_OPT_VERIFY_EMAIL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_EMAIL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify-email */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aVerify_EmailCantList,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_EMAIL_DESC, VERIFY_EMAIL_NAME, VERIFY_EMAIL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 16, VALUE_OPT_VERIFY_PURPOSE,
     /* equiv idx, value */ 16, VALUE_OPT_VERIFY_PURPOSE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_PURPOSE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify-purpose */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_PURPOSE_DESC, VERIFY_PURPOSE_NAME, VERIFY_PURPOSE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 17, VALUE_OPT_GENERATE_DH_PARAMS,
     /* equiv idx, value */ 17, VALUE_OPT_GENERATE_DH_PARAMS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_DH_PARAMS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-dh-params */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_DH_PARAMS_DESC, GENERATE_DH_PARAMS_NAME, GENERATE_DH_PARAMS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 18, VALUE_OPT_GET_DH_PARAMS,
     /* equiv idx, value */ 18, VALUE_OPT_GET_DH_PARAMS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GET_DH_PARAMS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --get-dh-params */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GET_DH_PARAMS_DESC, GET_DH_PARAMS_NAME, GET_DH_PARAMS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 19, VALUE_OPT_DH_INFO,
     /* equiv idx, value */ 19, VALUE_OPT_DH_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DH_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --dh-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DH_INFO_DESC, DH_INFO_NAME, DH_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 20, VALUE_OPT_LOAD_PRIVKEY,
     /* equiv idx, value */ 20, VALUE_OPT_LOAD_PRIVKEY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_PRIVKEY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-privkey */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_PRIVKEY_DESC, LOAD_PRIVKEY_NAME, LOAD_PRIVKEY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 21, VALUE_OPT_LOAD_PUBKEY,
     /* equiv idx, value */ 21, VALUE_OPT_LOAD_PUBKEY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_PUBKEY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-pubkey */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_PUBKEY_DESC, LOAD_PUBKEY_NAME, LOAD_PUBKEY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 22, VALUE_OPT_LOAD_REQUEST,
     /* equiv idx, value */ 22, VALUE_OPT_LOAD_REQUEST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_REQUEST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-request */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_REQUEST_DESC, LOAD_REQUEST_NAME, LOAD_REQUEST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 23, VALUE_OPT_LOAD_CERTIFICATE,
     /* equiv idx, value */ 23, VALUE_OPT_LOAD_CERTIFICATE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_CERTIFICATE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-certificate */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_CERTIFICATE_DESC, LOAD_CERTIFICATE_NAME, LOAD_CERTIFICATE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 24, VALUE_OPT_LOAD_CA_PRIVKEY,
     /* equiv idx, value */ 24, VALUE_OPT_LOAD_CA_PRIVKEY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_CA_PRIVKEY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-ca-privkey */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_CA_PRIVKEY_DESC, LOAD_CA_PRIVKEY_NAME, LOAD_CA_PRIVKEY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 25, VALUE_OPT_LOAD_CA_CERTIFICATE,
     /* equiv idx, value */ 25, VALUE_OPT_LOAD_CA_CERTIFICATE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_CA_CERTIFICATE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-ca-certificate */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_CA_CERTIFICATE_DESC, LOAD_CA_CERTIFICATE_NAME, LOAD_CA_CERTIFICATE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 26, VALUE_OPT_LOAD_CRL,
     /* equiv idx, value */ 26, VALUE_OPT_LOAD_CRL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_CRL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-crl */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_CRL_DESC, LOAD_CRL_NAME, LOAD_CRL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 27, VALUE_OPT_LOAD_DATA,
     /* equiv idx, value */ 27, VALUE_OPT_LOAD_DATA,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_DATA_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-data */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ LOAD_DATA_DESC, LOAD_DATA_NAME, LOAD_DATA_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 28, VALUE_OPT_PASSWORD,
     /* equiv idx, value */ 28, VALUE_OPT_PASSWORD,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PASSWORD_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --password */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PASSWORD_DESC, PASSWORD_NAME, PASSWORD_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 29, VALUE_OPT_NULL_PASSWORD,
     /* equiv idx, value */ 29, VALUE_OPT_NULL_PASSWORD,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ NULL_PASSWORD_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --null-password */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ NULL_PASSWORD_DESC, NULL_PASSWORD_NAME, NULL_PASSWORD_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 30, VALUE_OPT_EMPTY_PASSWORD,
     /* equiv idx, value */ 30, VALUE_OPT_EMPTY_PASSWORD,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ EMPTY_PASSWORD_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --empty-password */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ EMPTY_PASSWORD_DESC, EMPTY_PASSWORD_NAME, EMPTY_PASSWORD_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 31, VALUE_OPT_HEX_NUMBERS,
     /* equiv idx, value */ 31, VALUE_OPT_HEX_NUMBERS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ HEX_NUMBERS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --hex-numbers */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ HEX_NUMBERS_DESC, HEX_NUMBERS_NAME, HEX_NUMBERS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 32, VALUE_OPT_CPRINT,
     /* equiv idx, value */ 32, VALUE_OPT_CPRINT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ CPRINT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --cprint */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ CPRINT_DESC, CPRINT_NAME, CPRINT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 33, VALUE_OPT_CERTIFICATE_INFO,
     /* equiv idx, value */ 33, VALUE_OPT_CERTIFICATE_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ CERTIFICATE_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --certificate-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ CERTIFICATE_INFO_DESC, CERTIFICATE_INFO_NAME, CERTIFICATE_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 34, VALUE_OPT_FINGERPRINT,
     /* equiv idx, value */ 34, VALUE_OPT_FINGERPRINT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FINGERPRINT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --fingerprint */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ FINGERPRINT_DESC, FINGERPRINT_NAME, FINGERPRINT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 35, VALUE_OPT_KEY_ID,
     /* equiv idx, value */ 35, VALUE_OPT_KEY_ID,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ KEY_ID_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --key-id */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ KEY_ID_DESC, KEY_ID_NAME, KEY_ID_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 36, VALUE_OPT_CERTIFICATE_PUBKEY,
     /* equiv idx, value */ 36, VALUE_OPT_CERTIFICATE_PUBKEY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ CERTIFICATE_PUBKEY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --certificate-pubkey */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ CERTIFICATE_PUBKEY_DESC, CERTIFICATE_PUBKEY_NAME, CERTIFICATE_PUBKEY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 37, VALUE_OPT_PGP_CERTIFICATE_INFO,
     /* equiv idx, value */ 37, VALUE_OPT_PGP_CERTIFICATE_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PGP_CERTIFICATE_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pgp-certificate-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PGP_CERTIFICATE_INFO_DESC, PGP_CERTIFICATE_INFO_NAME, PGP_CERTIFICATE_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 38, VALUE_OPT_PGP_RING_INFO,
     /* equiv idx, value */ 38, VALUE_OPT_PGP_RING_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PGP_RING_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pgp-ring-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PGP_RING_INFO_DESC, PGP_RING_INFO_NAME, PGP_RING_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 39, VALUE_OPT_CRL_INFO,
     /* equiv idx, value */ 39, VALUE_OPT_CRL_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ CRL_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --crl-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ CRL_INFO_DESC, CRL_INFO_NAME, CRL_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 40, VALUE_OPT_CRQ_INFO,
     /* equiv idx, value */ 40, VALUE_OPT_CRQ_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ CRQ_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --crq-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ CRQ_INFO_DESC, CRQ_INFO_NAME, CRQ_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 41, VALUE_OPT_NO_CRQ_EXTENSIONS,
     /* equiv idx, value */ 41, VALUE_OPT_NO_CRQ_EXTENSIONS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ NO_CRQ_EXTENSIONS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --no-crq-extensions */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ NO_CRQ_EXTENSIONS_DESC, NO_CRQ_EXTENSIONS_NAME, NO_CRQ_EXTENSIONS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 42, VALUE_OPT_P12_INFO,
     /* equiv idx, value */ 42, VALUE_OPT_P12_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P12_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p12-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P12_INFO_DESC, P12_INFO_NAME, P12_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 43, VALUE_OPT_P12_NAME,
     /* equiv idx, value */ 43, VALUE_OPT_P12_NAME,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P12_NAME_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p12-name */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P12_NAME_DESC, P12_NAME_NAME, P12_NAME_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 44, VALUE_OPT_P7_GENERATE,
     /* equiv idx, value */ 44, VALUE_OPT_P7_GENERATE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_GENERATE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-generate */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_GENERATE_DESC, P7_GENERATE_NAME, P7_GENERATE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 45, VALUE_OPT_P7_SIGN,
     /* equiv idx, value */ 45, VALUE_OPT_P7_SIGN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_SIGN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-sign */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_SIGN_DESC, P7_SIGN_NAME, P7_SIGN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 46, VALUE_OPT_P7_DETACHED_SIGN,
     /* equiv idx, value */ 46, VALUE_OPT_P7_DETACHED_SIGN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_DETACHED_SIGN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-detached-sign */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_DETACHED_SIGN_DESC, P7_DETACHED_SIGN_NAME, P7_DETACHED_SIGN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 47, VALUE_OPT_P7_INCLUDE_CERT,
     /* equiv idx, value */ 47, VALUE_OPT_P7_INCLUDE_CERT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_INCLUDE_CERT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-include-cert */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_INCLUDE_CERT_DESC, P7_INCLUDE_CERT_NAME, P7_INCLUDE_CERT_name,
     /* disablement strs */ NOT_P7_INCLUDE_CERT_name, NOT_P7_INCLUDE_CERT_PFX },

  {  /* entry idx, value */ 48, VALUE_OPT_P7_TIME,
     /* equiv idx, value */ 48, VALUE_OPT_P7_TIME,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_TIME_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-time */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_TIME_DESC, P7_TIME_NAME, P7_TIME_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 49, VALUE_OPT_P7_SHOW_DATA,
     /* equiv idx, value */ 49, VALUE_OPT_P7_SHOW_DATA,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_SHOW_DATA_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-show-data */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_SHOW_DATA_DESC, P7_SHOW_DATA_NAME, P7_SHOW_DATA_name,
     /* disablement strs */ NOT_P7_SHOW_DATA_name, NOT_P7_SHOW_DATA_PFX },

  {  /* entry idx, value */ 50, VALUE_OPT_P7_INFO,
     /* equiv idx, value */ 50, VALUE_OPT_P7_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_INFO_DESC, P7_INFO_NAME, P7_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 51, VALUE_OPT_P7_VERIFY,
     /* equiv idx, value */ 51, VALUE_OPT_P7_VERIFY,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P7_VERIFY_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p7-verify */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P7_VERIFY_DESC, P7_VERIFY_NAME, P7_VERIFY_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 52, VALUE_OPT_P8_INFO,
     /* equiv idx, value */ 52, VALUE_OPT_P8_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ P8_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --p8-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ P8_INFO_DESC, P8_INFO_NAME, P8_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 53, VALUE_OPT_SMIME_TO_P7,
     /* equiv idx, value */ 53, VALUE_OPT_SMIME_TO_P7,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SMIME_TO_P7_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --smime-to-p7 */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SMIME_TO_P7_DESC, SMIME_TO_P7_NAME, SMIME_TO_P7_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 54, VALUE_OPT_KEY_INFO,
     /* equiv idx, value */ 54, VALUE_OPT_KEY_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ KEY_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --key-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ KEY_INFO_DESC, KEY_INFO_NAME, KEY_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 55, VALUE_OPT_PGP_KEY_INFO,
     /* equiv idx, value */ 55, VALUE_OPT_PGP_KEY_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PGP_KEY_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pgp-key-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PGP_KEY_INFO_DESC, PGP_KEY_INFO_NAME, PGP_KEY_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 56, VALUE_OPT_PUBKEY_INFO,
     /* equiv idx, value */ 56, VALUE_OPT_PUBKEY_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PUBKEY_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pubkey-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PUBKEY_INFO_DESC, PUBKEY_INFO_NAME, PUBKEY_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 57, VALUE_OPT_V1,
     /* equiv idx, value */ 57, VALUE_OPT_V1,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ V1_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --v1 */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ V1_DESC, V1_NAME, V1_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 58, VALUE_OPT_TO_P12,
     /* equiv idx, value */ 58, VALUE_OPT_TO_P12,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TO_P12_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --to-p12 */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aTo_P12MustList, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ TO_P12_DESC, TO_P12_NAME, TO_P12_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 59, VALUE_OPT_TO_P8,
     /* equiv idx, value */ 59, VALUE_OPT_TO_P8,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TO_P8_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --to-p8 */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ TO_P8_DESC, TO_P8_NAME, TO_P8_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 60, VALUE_OPT_PKCS8,
     /* equiv idx, value */ 60, VALUE_OPT_PKCS8,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PKCS8_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pkcs8 */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PKCS8_DESC, PKCS8_NAME, PKCS8_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 61, VALUE_OPT_RSA,
     /* equiv idx, value */ 61, VALUE_OPT_RSA,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ RSA_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --rsa */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ RSA_DESC, RSA_NAME, RSA_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 62, VALUE_OPT_DSA,
     /* equiv idx, value */ 62, VALUE_OPT_DSA,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DSA_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --dsa */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DSA_DESC, DSA_NAME, DSA_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 63, VALUE_OPT_ECC,
     /* equiv idx, value */ 63, VALUE_OPT_ECC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ECC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --ecc */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ECC_DESC, ECC_NAME, ECC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 64, VALUE_OPT_ECDSA,
     /* equiv idx, value */ 64, VALUE_OPT_ECDSA,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ECDSA_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --ecdsa */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptEcdsa,
     /* desc, NAME, name */ ECDSA_DESC, ECDSA_NAME, ECDSA_name,
     /* disablement strs */ 0, 0 },

  {  /* entry idx, value */ 65, VALUE_OPT_HASH,
     /* equiv idx, value */ 65, VALUE_OPT_HASH,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ HASH_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --hash */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ HASH_DESC, HASH_NAME, HASH_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 66, VALUE_OPT_INDER,
     /* equiv idx, value */ 66, VALUE_OPT_INDER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ INDER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --inder */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ INDER_DESC, INDER_NAME, INDER_name,
     /* disablement strs */ NOT_INDER_name, NOT_INDER_PFX },

  {  /* entry idx, value */ 67, VALUE_OPT_INRAW,
     /* equiv idx, value */ 67, VALUE_OPT_INRAW,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ INRAW_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --inraw */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptInraw,
     /* desc, NAME, name */ INRAW_DESC, INRAW_NAME, INRAW_name,
     /* disablement strs */ 0, 0 },

  {  /* entry idx, value */ 68, VALUE_OPT_OUTDER,
     /* equiv idx, value */ 68, VALUE_OPT_OUTDER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OUTDER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --outder */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ OUTDER_DESC, OUTDER_NAME, OUTDER_name,
     /* disablement strs */ NOT_OUTDER_name, NOT_OUTDER_PFX },

  {  /* entry idx, value */ 69, VALUE_OPT_OUTRAW,
     /* equiv idx, value */ 69, VALUE_OPT_OUTRAW,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OUTRAW_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --outraw */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptOutraw,
     /* desc, NAME, name */ OUTRAW_DESC, OUTRAW_NAME, OUTRAW_name,
     /* disablement strs */ 0, 0 },

  {  /* entry idx, value */ 70, VALUE_OPT_BITS,
     /* equiv idx, value */ 70, VALUE_OPT_BITS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ BITS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --bits */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ BITS_DESC, BITS_NAME, BITS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 71, VALUE_OPT_CURVE,
     /* equiv idx, value */ 71, VALUE_OPT_CURVE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ CURVE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --curve */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ CURVE_DESC, CURVE_NAME, CURVE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 72, VALUE_OPT_SEC_PARAM,
     /* equiv idx, value */ 72, VALUE_OPT_SEC_PARAM,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SEC_PARAM_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --sec-param */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SEC_PARAM_DESC, SEC_PARAM_NAME, SEC_PARAM_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 73, VALUE_OPT_DISABLE_QUICK_RANDOM,
     /* equiv idx, value */ 73, VALUE_OPT_DISABLE_QUICK_RANDOM,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DISABLE_QUICK_RANDOM_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --disable-quick-random */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DISABLE_QUICK_RANDOM_DESC, DISABLE_QUICK_RANDOM_NAME, DISABLE_QUICK_RANDOM_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 74, VALUE_OPT_TEMPLATE,
     /* equiv idx, value */ 74, VALUE_OPT_TEMPLATE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TEMPLATE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --template */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ TEMPLATE_DESC, TEMPLATE_NAME, TEMPLATE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 75, VALUE_OPT_STDOUT_INFO,
     /* equiv idx, value */ 75, VALUE_OPT_STDOUT_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ STDOUT_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --stdout-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ STDOUT_INFO_DESC, STDOUT_INFO_NAME, STDOUT_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 76, VALUE_OPT_ASK_PASS,
     /* equiv idx, value */ 76, VALUE_OPT_ASK_PASS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ASK_PASS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --ask-pass */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ASK_PASS_DESC, ASK_PASS_NAME, ASK_PASS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 77, VALUE_OPT_PKCS_CIPHER,
     /* equiv idx, value */ 77, VALUE_OPT_PKCS_CIPHER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PKCS_CIPHER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pkcs-cipher */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PKCS_CIPHER_DESC, PKCS_CIPHER_NAME, PKCS_CIPHER_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 78, VALUE_OPT_PROVIDER,
     /* equiv idx, value */ 78, VALUE_OPT_PROVIDER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PROVIDER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --provider */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ PROVIDER_DESC, PROVIDER_NAME, PROVIDER_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_VERSION, VALUE_OPT_VERSION,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_VERSION,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VER_FLAGS, AOUSE_VERSION,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ VER_PROC,
     /* desc, NAME, name */ VER_DESC, NULL, VER_name,
     /* disablement strs */ NULL, NULL },



  {  /* entry idx, value */ INDEX_OPT_HELP, VALUE_OPT_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OPTST_IMM | OPTST_NO_INIT, AOUSE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doUsageOpt,
     /* desc, NAME, name */ HELP_DESC, NULL, HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_MORE_HELP, VALUE_OPT_MORE_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_MORE_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MORE_HELP_FLAGS, AOUSE_MORE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL,  NULL,
     /* option proc      */ optionPagedUsage,
     /* desc, NAME, name */ MORE_HELP_DESC, NULL, MORE_HELP_name,
     /* disablement strs */ NULL, NULL }
};


/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/** Reference to the upper cased version of certtool. */
#define zPROGNAME       (certtool_opt_strs+5915)
/** Reference to the title line for certtool usage. */
#define zUsageTitle     (certtool_opt_strs+5924)
/** There is no certtool configuration file. */
#define zRcName         NULL
/** There are no directories to search for certtool config files. */
#define apzHomeList     NULL
/** The certtool program bug email address. */
#define zBugsAddr       (certtool_opt_strs+6017)
/** Clarification/explanation of what certtool does. */
#define zExplain        (certtool_opt_strs+6033)
/** Extra detail explaining what certtool does. */
#define zDetail         (certtool_opt_strs+6035)
/** The full version string for certtool. */
#define zFullVersion    (certtool_opt_strs+6386)
/* extracted from optcode.tlib near line 364 */

#if defined(ENABLE_NLS)
# define OPTPROC_BASE OPTPROC_TRANSLATE | OPTPROC_NXLAT_OPT
  static tOptionXlateProc translate_option_strings;
#else
# define OPTPROC_BASE OPTPROC_NONE
# define translate_option_strings NULL
#endif /* ENABLE_NLS */

#define certtool_full_usage (NULL)
#define certtool_short_usage (certtool_opt_strs+6402)

#endif /* not defined __doxygen__ */

/*
 *  Create the static procedure(s) declared above.
 */
/**
 * The callout function that invokes the optionUsage function.
 *
 * @param[in] opts the AutoOpts option description structure
 * @param[in] od   the descriptor for the "help" (usage) option.
 * @noreturn
 */
static void
doUsageOpt(tOptions * opts, tOptDesc * od)
{
    int ex_code;
    ex_code = CERTTOOL_EXIT_SUCCESS;
    optionUsage(&certtoolOptions, ex_code);
    /* NOTREACHED */
    exit(CERTTOOL_EXIT_FAILURE);
    (void)opts;
    (void)od;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the debug option.
 * Specifies the debug level.
 * @param[in] pOptions the certtool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptDebug(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0 ,  9999 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the infile option.
 *
 * @param[in] pOptions the certtool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptInfile(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the ecdsa option.
 *
 * @param[in] pOptions the certtool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEcdsa(tOptions* pOptions, tOptDesc* pOptDesc)
{
    int res = optionAlias(pOptions, pOptDesc, INDEX_OPT_ECC);
    if ((res != 0) && ((pOptions->fOptSet & OPTPROC_ERRSTOP) != 0))
        USAGE(CERTTOOL_EXIT_USAGE_ERROR);

}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the inraw option.
 *
 * @param[in] pOptions the certtool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptInraw(tOptions* pOptions, tOptDesc* pOptDesc)
{
    int res = optionAlias(pOptions, pOptDesc, INDEX_OPT_INDER);
    if ((res != 0) && ((pOptions->fOptSet & OPTPROC_ERRSTOP) != 0))
        USAGE(CERTTOOL_EXIT_USAGE_ERROR);

}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the outraw option.
 *
 * @param[in] pOptions the certtool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptOutraw(tOptions* pOptions, tOptDesc* pOptDesc)
{
    int res = optionAlias(pOptions, pOptDesc, INDEX_OPT_OUTDER);
    if ((res != 0) && ((pOptions->fOptSet & OPTPROC_ERRSTOP) != 0))
        USAGE(CERTTOOL_EXIT_USAGE_ERROR);

}
/* extracted from optmain.tlib near line 1250 */

/**
 * The directory containing the data associated with certtool.
 */
#ifndef  PKGDATADIR
# define PKGDATADIR ""
#endif

/**
 * Information about the person or institution that packaged certtool
 * for the current distribution.
 */
#ifndef  WITH_PACKAGER
# define certtool_packager_info NULL
#else
/** Packager information for certtool. */
static char const certtool_packager_info[] =
    "Packaged by " WITH_PACKAGER

# ifdef WITH_PACKAGER_VERSION
        " ("WITH_PACKAGER_VERSION")"
# endif

# ifdef WITH_PACKAGER_BUG_REPORTS
    "\nReport certtool bugs to " WITH_PACKAGER_BUG_REPORTS
# endif
    "\n";
#endif
#ifndef __doxygen__

#endif /* __doxygen__ */
/**
 * The option definitions for certtool.  The one structure that
 * binds them all.
 */
tOptions certtoolOptions = {
    OPTIONS_STRUCT_VERSION,
    0, NULL,                    /* original argc + argv    */
    ( OPTPROC_BASE
    + OPTPROC_ERRSTOP
    + OPTPROC_SHORTOPT
    + OPTPROC_LONGOPT
    + OPTPROC_NO_REQ_OPT
    + OPTPROC_NEGATIONS
    + OPTPROC_NO_ARGS
    + OPTPROC_GNUUSAGE
    + OPTPROC_MISUSE ),
    0, NULL,                    /* current option index, current option */
    NULL,         NULL,         zPROGNAME,
    zRcName,      zCopyright,   zLicenseDescrip,
    zFullVersion, apzHomeList,  zUsageTitle,
    zExplain,     zDetail,      optDesc,
    zBugsAddr,                  /* address to send bugs to */
    NULL, NULL,                 /* extensions/saved state  */
    optionUsage, /* usage procedure */
    translate_option_strings,   /* translation procedure */
    /*
     *  Indexes to special options
     */
    { INDEX_OPT_MORE_HELP, /* more-help option index */
      NO_EQUIVALENT, /* save option index */
      NO_EQUIVALENT, /* '-#' option index */
      NO_EQUIVALENT /* index of default opt */
    },
    82 /* full option count */, 79 /* user option count */,
    certtool_full_usage, certtool_short_usage,
    NULL, NULL,
    PKGDATADIR, certtool_packager_info
};

#if ENABLE_NLS
/**
 * This code is designed to translate translatable option text for the
 * certtool program.  These translations happen upon entry
 * to optionProcess().
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#ifdef HAVE_DCGETTEXT
# include <gettext.h>
#endif
#include <autoopts/usage-txt.h>

static char * AO_gettext(char const * pz);
static void   coerce_it(void ** s);

/**
 * AutoGen specific wrapper function for gettext.  It relies on the macro _()
 * to convert from English to the target language, then strdup-duplicates the
 * result string.  It tries the "libopts" domain first, then whatever has been
 * set via the \a textdomain(3) call.
 *
 * @param[in] pz the input text used as a lookup key.
 * @returns the translated text (if there is one),
 *   or the original text (if not).
 */
static char *
AO_gettext(char const * pz)
{
    char * res;
    if (pz == NULL)
        return NULL;
#ifdef HAVE_DCGETTEXT
    /*
     * While processing the option_xlateable_txt data, try to use the
     * "libopts" domain.  Once we switch to the option descriptor data,
     * do *not* use that domain.
     */
    if (option_xlateable_txt.field_ct != 0) {
        res = dgettext("libopts", pz);
        if (res == pz)
            res = (char *)VOIDP(_(pz));
    } else
        res = (char *)VOIDP(_(pz));
#else
    res = (char *)VOIDP(_(pz));
#endif
    if (res == pz)
        return res;
    res = strdup(res);
    if (res == NULL) {
        fputs(_("No memory for duping translated strings\n"), stderr);
        exit(CERTTOOL_EXIT_FAILURE);
    }
    return res;
}

/**
 * All the pointers we use are marked "* const", but they are stored in
 * writable memory.  Coerce the mutability and set the pointer.
 */
static void coerce_it(void ** s) { *s = AO_gettext(*s);
}

/**
 * Translate all the translatable strings in the certtoolOptions
 * structure defined above.  This is done only once.
 */
static void
translate_option_strings(void)
{
    tOptions * const opts = &certtoolOptions;

    /*
     *  Guard against re-translation.  It won't work.  The strings will have
     *  been changed by the first pass through this code.  One shot only.
     */
    if (option_xlateable_txt.field_ct != 0) {
        /*
         *  Do the translations.  The first pointer follows the field count
         *  field.  The field count field is the size of a pointer.
         */
        char ** ppz = (char**)VOIDP(&(option_xlateable_txt));
        int     ix  = option_xlateable_txt.field_ct;

        do {
            ppz++; /* skip over field_ct */
            *ppz = AO_gettext(*ppz);
        } while (--ix > 0);
        /* prevent re-translation and disable "libopts" domain lookup */
        option_xlateable_txt.field_ct = 0;

        coerce_it(VOIDP(&(opts->pzCopyright)));
        coerce_it(VOIDP(&(opts->pzCopyNotice)));
        coerce_it(VOIDP(&(opts->pzFullVersion)));
        coerce_it(VOIDP(&(opts->pzUsageTitle)));
        coerce_it(VOIDP(&(opts->pzExplain)));
        coerce_it(VOIDP(&(opts->pzDetail)));
        {
            tOptDesc * od = opts->pOptDesc;
            for (ix = opts->optCt; ix > 0; ix--, od++)
                coerce_it(VOIDP(&(od->pzText)));
        }
    }
}
#endif /* ENABLE_NLS */

#ifdef DO_NOT_COMPILE_THIS_CODE_IT_IS_FOR_GETTEXT
/** I18N function strictly for xgettext.  Do not compile. */
static void bogus_function(void) {
  /* TRANSLATORS:

     The following dummy function was crated solely so that xgettext can
     extract the correct strings.  These strings are actually referenced
     by a field name in the certtoolOptions structure noted in the
     comments below.  The literal text is defined in certtool_opt_strs.
   
     NOTE: the strings below are segmented with respect to the source string
     certtool_opt_strs.  The strings above are handed off for translation
     at run time a paragraph at a time.  Consequently, they are presented here
     for translation a paragraph at a time.
   
     ALSO: often the description for an option will reference another option
     by name.  These are set off with apostrophe quotes (I hope).  Do not
     translate option names.
   */
  /* referenced via certtoolOptions.pzCopyright */
  puts(_("certtool 3.4.15\n\
Copyright (C) 2000-2016 Free Software Foundation, and others, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the GNU General Public License,\n\
version 3 or later <http://gnu.org/licenses/gpl.html>\n"));

  /* referenced via certtoolOptions.pzCopyNotice */
  puts(_("certtool is free software: you can redistribute it and/or modify it under\n\
the terms of the GNU General Public License as published by the Free\n\
Software Foundation, either version 3 of the License, or (at your option)\n\
any later version.\n\n"));
  puts(_("certtool is distributed in the hope that it will be useful, but WITHOUT ANY\n\
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS\n\
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more\n\
details.\n\n"));
  puts(_("You should have received a copy of the GNU General Public License along\n\
with this program.  If not, see <http://www.gnu.org/licenses/>.\n"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Enable debugging"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("More verbose output"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Input file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Output file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a self-signed certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a signed certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generates a proxy certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a CRL"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Update a signed certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a private key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a PKCS #10 certificate request"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Verify a PEM encoded certificate chain"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Verify a PEM encoded certificate chain using a trusted list"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Verify a CRL using a trusted list"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Specify a hostname to be used for certificate chain verification"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Specify a email to be used for certificate chain verification"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Specify a purpose OID to be used for certificate chain verification"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate PKCS #3 encoded Diffie-Hellman parameters"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Get the included PKCS #3 encoded Diffie-Hellman parameters"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information PKCS #3 encoded Diffie-Hellman parameters"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads a private key file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads a public key file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads a certificate request file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads a certificate file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads the certificate authority's private key file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads the certificate authority's certificate file"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads the provided CRL"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Loads auxilary data"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Password to use"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Enforce a NULL password"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Enforce an empty password"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print big number in an easier format to parse"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("In certain operations it prints the information in C-friendly format"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on the given certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print the fingerprint of the given certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print the key ID of the given certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print certificate's public key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on the given OpenPGP certificate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on the given OpenPGP keyring structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on the given CRL structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on the given certificate request"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Do not use extensions in certificate requests"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on a PKCS #12 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("The PKCS #12 friendly name to use"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Signs using a PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Signs using a detached PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("The signer's certificate will be included in the cert list."));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Will include a timestamp in the PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Will show the embedded data in the PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on a PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Verify the provided PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on a PKCS #8 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Convert S/MIME to PKCS #7 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on a private key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on an OpenPGP private key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information on a public key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate an X.509 version 1 certificate (with no extensions)"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a PKCS #12 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate a PKCS #8 structure"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Use PKCS #8 format for private keys"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate RSA key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate DSA key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Generate ECC (ECDSA) key"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("an alias for the 'ecc' option"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Hash algorithm to use for signing"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Use DER format for input certificates, private keys, and DH parameters"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("an alias for the 'inder' option"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Use DER format for output certificates, private keys, and DH parameters"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("an alias for the 'outder' option"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Specify the number of bits for key generate"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Specify the curve used for EC key generation"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Specify the security level [low, legacy, medium, high, ultra]"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("No effect"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Template file to use for non-interactive operation"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Print information to stdout instead of stderr"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Enable interaction for entering password when in batch mode."));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Cipher to use for PKCS #8 and #12 operations"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("Specify the PKCS #11 provider library"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("display extended usage information and exit"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("extended usage information passed thru pager"));

  /* referenced via certtoolOptions.pOptDesc->pzText */
  puts(_("output version information and exit"));

  /* referenced via certtoolOptions.pzUsageTitle */
  puts(_("certtool - GnuTLS certificate tool\n\
Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n"));

  /* referenced via certtoolOptions.pzExplain */
  puts(_("\n"));

  /* referenced via certtoolOptions.pzDetail */
  puts(_("Tool to parse and generate X.509 certificates, requests and private keys.\n\
It can be used interactively or non interactively by specifying the\n\
template command line option.\n\n"));
  puts(_("The tool accepts files or URLs supported by GnuTLS.  In case PIN is\n\
required for the URL access you can provide it using the environment\n\
variables GNUTLS_PIN and GNUTLS_SO_PIN.\n"));

  /* referenced via certtoolOptions.pzFullVersion */
  puts(_("certtool 3.4.15"));

  /* referenced via certtoolOptions.pzFullUsage */
  puts(_("<<<NOT-FOUND>>>"));

  /* referenced via certtoolOptions.pzShortUsage */
  puts(_("certtool [options]\n\
certtool --help for usage instructions.\n"));
  /* LIBOPTS-MESSAGES: */
#line 67 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 93 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 53 "../init.c"
  puts(_("AutoOpts function called without option descriptor\n"));
#line 86 "../init.c"
  puts(_("\tThis exceeds the compiled library version:  "));
#line 84 "../init.c"
  puts(_("Automated Options Processing Error!\n"
       "\t%s called AutoOpts function with structure version %d:%d:%d.\n"));
#line 80 "../autoopts.c"
  puts(_("realloc of %d bytes at 0x%p failed\n"));
#line 88 "../init.c"
  puts(_("\tThis is less than the minimum library version:  "));
#line 121 "../version.c"
  puts(_("Automated Options version %s\n"
       "\tCopyright (C) 1999-2014 by Bruce Korb - all rights reserved\n"));
#line 87 "../makeshell.c"
  puts(_("(AutoOpts bug):  %s.\n"));
#line 90 "../reset.c"
  puts(_("optionResetOpt() called, but reset-option not configured"));
#line 292 "../usage.c"
  puts(_("could not locate the 'help' option"));
#line 336 "../autoopts.c"
  puts(_("optionProcess() was called with invalid data"));
#line 748 "../usage.c"
  puts(_("invalid argument type specified"));
#line 598 "../find.c"
  puts(_("defaulted to option with optional arg"));
#line 76 "../alias.c"
  puts(_("aliasing option is out of range."));
#line 235 "../enum.c"
  puts(_("%s error:  the keyword '%s' is ambiguous for %s\n"));
#line 108 "../find.c"
  puts(_("  The following options match:\n"));
#line 293 "../find.c"
  puts(_("%s: ambiguous option name: %s (matches %d options)\n"));
#line 161 "../check.c"
  puts(_("%s: Command line arguments required\n"));
#line 43 "../alias.c"
  puts(_("%d %s%s options allowed\n"));
#line 94 "../makeshell.c"
  puts(_("%s error %d (%s) calling %s for '%s'\n"));
#line 306 "../makeshell.c"
  puts(_("interprocess pipe"));
#line 168 "../version.c"
  puts(_("error: version option argument '%c' invalid.  Use:\n"
       "\t'v' - version only\n"
       "\t'c' - version and copyright\n"
       "\t'n' - version and full copyright notice\n"));
#line 58 "../check.c"
  puts(_("%s error:  the '%s' and '%s' options conflict\n"));
#line 217 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 430 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 38 "../alias.c"
  puts(_("-equivalence"));
#line 469 "../find.c"
  puts(_("%s: illegal option -- %c\n"));
#line 110 "../reset.c"
  puts(_("%s: illegal option -- %c\n"));
#line 271 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 755 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 118 "../reset.c"
  puts(_("%s: illegal option -- %s\n"));
#line 335 "../find.c"
  puts(_("%s: unknown vendor extension option -- %s\n"));
#line 160 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 170 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 747 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 1081 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 385 "../find.c"
  puts(_("%s: invalid option name: %s\n"));
#line 527 "../find.c"
  puts(_("%s: The '%s' option requires an argument.\n"));
#line 156 "../autoopts.c"
  puts(_("(AutoOpts bug):  Equivalenced option '%s' was equivalenced to both\n"
       "\t'%s' and '%s'."));
#line 94 "../check.c"
  puts(_("%s error:  The %s option is required\n"));
#line 632 "../find.c"
  puts(_("%s: The '%s' option cannot have an argument.\n"));
#line 151 "../check.c"
  puts(_("%s: Command line arguments are not allowed.\n"));
#line 535 "../save.c"
  puts(_("error %d (%s) creating %s\n"));
#line 235 "../enum.c"
  puts(_("%s error:  '%s' does not match any %s keywords.\n"));
#line 93 "../reset.c"
  puts(_("%s error: The '%s' option requires an argument.\n"));
#line 186 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 238 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 143 "../restore.c"
  puts(_("%s error: no saved option state\n"));
#line 231 "../autoopts.c"
  puts(_("'%s' is not a command line option.\n"));
#line 113 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable date/time.\n"));
#line 131 "../save.c"
  puts(_("'%s' not defined\n"));
#line 50 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable time duration.\n"));
#line 92 "../check.c"
  puts(_("%s error:  The %s option must appear %d times.\n"));
#line 165 "../numeric.c"
  puts(_("%s error:  '%s' is not a recognizable number.\n"));
#line 201 "../enum.c"
  puts(_("%s error:  %s exceeds %s keyword count\n"));
#line 330 "../usage.c"
  puts(_("Try '%s %s' for more information.\n"));
#line 45 "../alias.c"
  puts(_("one %s%s option allowed\n"));
#line 208 "../makeshell.c"
  puts(_("standard output"));
#line 943 "../makeshell.c"
  puts(_("standard output"));
#line 274 "../usage.c"
  puts(_("standard output"));
#line 415 "../usage.c"
  puts(_("standard output"));
#line 625 "../usage.c"
  puts(_("standard output"));
#line 175 "../version.c"
  puts(_("standard output"));
#line 274 "../usage.c"
  puts(_("standard error"));
#line 415 "../usage.c"
  puts(_("standard error"));
#line 625 "../usage.c"
  puts(_("standard error"));
#line 175 "../version.c"
  puts(_("standard error"));
#line 208 "../makeshell.c"
  puts(_("write"));
#line 943 "../makeshell.c"
  puts(_("write"));
#line 273 "../usage.c"
  puts(_("write"));
#line 414 "../usage.c"
  puts(_("write"));
#line 624 "../usage.c"
  puts(_("write"));
#line 174 "../version.c"
  puts(_("write"));
#line 60 "../numeric.c"
  puts(_("%s error:  %s option value %ld is out of range.\n"));
#line 44 "../check.c"
  puts(_("%s error:  %s option requires the %s option\n"));
#line 130 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 185 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 237 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 256 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 534 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
  /* END-LIBOPTS-MESSAGES */

  /* USAGE-TEXT: */
#line 873 "../usage.c"
  puts(_("\t\t\t\t- an alternate for '%s'\n"));
#line 1148 "../usage.c"
  puts(_("Version, usage and configuration options:"));
#line 924 "../usage.c"
  puts(_("\t\t\t\t- default option for unnamed options\n"));
#line 837 "../usage.c"
  puts(_("\t\t\t\t- disabled as '--%s'\n"));
#line 1117 "../usage.c"
  puts(_(" --- %-14s %s\n"));
#line 1115 "../usage.c"
  puts(_("This option has been disabled"));
#line 864 "../usage.c"
  puts(_("\t\t\t\t- enabled by default\n"));
#line 40 "../alias.c"
  puts(_("%s error:  only "));
#line 1194 "../usage.c"
  puts(_(" - examining environment variables named %s_*\n"));
#line 168 "../file.c"
  puts(_("\t\t\t\t- file must not pre-exist\n"));
#line 172 "../file.c"
  puts(_("\t\t\t\t- file must pre-exist\n"));
#line 380 "../usage.c"
  puts(_("Options are specified by doubled hyphens and their name or by a single\n"
       "hyphen and the flag character.\n"));
#line 921 "../makeshell.c"
  puts(_("\n"
       "= = = = = = = =\n\n"
       "This incarnation of genshell will produce\n"
       "a shell script to parse the options for %s:\n\n"));
#line 167 "../enum.c"
  puts(_("  or an integer mask with any of the lower %d bits set\n"));
#line 897 "../usage.c"
  puts(_("\t\t\t\t- is a set membership option\n"));
#line 918 "../usage.c"
  puts(_("\t\t\t\t- must appear between %d and %d times\n"));
#line 382 "../usage.c"
  puts(_("Options are specified by single or double hyphens and their name.\n"));
#line 904 "../usage.c"
  puts(_("\t\t\t\t- may appear multiple times\n"));
#line 891 "../usage.c"
  puts(_("\t\t\t\t- may not be preset\n"));
#line 1309 "../usage.c"
  puts(_("   Arg Option-Name    Description\n"));
#line 1245 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1303 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1304 "../usage.c"
  puts(_(" %3s %s"));
#line 1310 "../usage.c"
  puts(_(" %3s %s"));
#line 387 "../usage.c"
  puts(_("The '-#<number>' option may omit the hash char\n"));
#line 383 "../usage.c"
  puts(_("All arguments are named options.\n"));
#line 971 "../usage.c"
  puts(_(" - reading file %s"));
#line 409 "../usage.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 100 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 129 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 903 "../usage.c"
  puts(_("\t\t\t\t- may NOT appear - preset only\n"));
#line 944 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 1192 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 682 "../usage.c"
  puts(_("prohibits these options:\n"));
#line 677 "../usage.c"
  puts(_("prohibits the option '%s'\n"));
#line 81 "../numeric.c"
  puts(_("%s%ld to %ld"));
#line 79 "../numeric.c"
  puts(_("%sgreater than or equal to %ld"));
#line 75 "../numeric.c"
  puts(_("%s%ld exactly"));
#line 68 "../numeric.c"
  puts(_("%sit must lie in one of the ranges:\n"));
#line 68 "../numeric.c"
  puts(_("%sit must be in the range:\n"));
#line 88 "../numeric.c"
  puts(_(", or\n"));
#line 66 "../numeric.c"
  puts(_("%sis scalable with a suffix: k/K/m/M/g/G/t/T\n"));
#line 77 "../numeric.c"
  puts(_("%sless than or equal to %ld"));
#line 390 "../usage.c"
  puts(_("Operands and options may be intermixed.  They will be reordered.\n"));
#line 652 "../usage.c"
  puts(_("requires the option '%s'\n"));
#line 655 "../usage.c"
  puts(_("requires these options:\n"));
#line 1321 "../usage.c"
  puts(_("   Arg Option-Name   Req?  Description\n"));
#line 1315 "../usage.c"
  puts(_("  Flg Arg Option-Name   Req?  Description\n"));
#line 168 "../enum.c"
  puts(_("or you may use a numeric representation.  Preceding these with a '!'\n"
       "will clear the bits, specifying 'none' will clear all bits, and 'all'\n"
       "will set them all.  Multiple entries may be passed as an option\n"
       "argument list.\n"));
#line 910 "../usage.c"
  puts(_("\t\t\t\t- may appear up to %d times\n"));
#line 77 "../enum.c"
  puts(_("The valid \"%s\" option keywords are:\n"));
#line 1152 "../usage.c"
  puts(_("The next option supports vendor supported extra options:"));
#line 773 "../usage.c"
  puts(_("These additional options are:"));
  /* END-USAGE-TEXT */
}
#endif /* uncompilable code */
#ifdef  __cplusplus
}
#endif
/* certtool-args.c ends here */
